@@ -29,7 +29,7 @@ class ai_building_place_with_road_finder : public building_placefinder_t  {
 public:
 	ai_building_place_with_road_finder(karte_t *welt) : building_placefinder_t(welt) {}
 	bool is_road_at(sint16 x, sint16 y) const;
-	virtual bool is_area_ok(koord pos, sint16 w, sint16 h, climate_bits cl) const;
+	bool is_area_ok(koord pos, sint16 w, sint16 h, climate_bits cl) const OVERRIDE;
 };
 
 
@@ -64,7 +64,7 @@ public:
 	sint32 get_construction_speed() const { return construction_speed; }
 	virtual void set_construction_speed( sint32 newspeed ) { construction_speed = newspeed; }
 
-	virtual void rdwr(loadsave_t *file);
+	void rdwr(loadsave_t *file) OVERRIDE;
 
 	// return true, if there is already a connection
 	bool is_connected(const koord star_pos, const koord end_pos, const goods_desc_t *wtyp) const;
