@@ -269,7 +269,7 @@ bool baum_t::successfully_loaded()
 	tree_list_per_climate = new weighted_vector_tpl<uint32>[MAX_CLIMATES];
 
 	// clear cache
-	memset( tree_id_to_image, -1, lengthof(tree_id_to_image) );
+	memset( tree_id_to_image, -1, sizeof(tree_id_to_image) );
 	// now register all trees for all fitting climates
 	for(  uint32 typ=0;  typ<tree_list.get_count()-1;  typ++  ) {
 		// add this tree to climates
@@ -561,7 +561,7 @@ void baum_t::rdwr(loadsave_t *file)
 	}
 
 	// z-offset
-	if(file->get_version() > 111000) {
+	if(file->is_version_atleast(111, 1)) {
 		uint8 zoff_ = zoff;
 		file->rdwr_byte(zoff_);
 		zoff = zoff_;
@@ -610,6 +610,11 @@ void baum_t::info(cbuffer_t & buf) const
 	buf.append( "\n" );
 	uint32 age = get_age();
 	buf.printf( translator::translate("%i years %i months old."), age/12, (age%12) );
+
+	if (char const* const maker = get_desc()->get_copyright()) {
+		buf.append("\n\n");
+		buf.printf(translator::translate("Constructed by %s"), maker);
+	}
 }
 
 
