@@ -22,7 +22,7 @@
 #include "../boden/brueckenboden.h"
 
 #include "../gui/tool_selector.h"
-#include "../gui/karte.h"
+#include "../gui/minimap.h"
 
 #include "../descriptor/bridge_desc.h"
 
@@ -214,8 +214,8 @@ const char *check_tile( const grund_t *gr, const player_t *player, waytype_t wt,
 			return "A bridge must start on a way!";
 		}
 
-		// same waytype, any direction, no stop or depot or any other stuff */
-		if(  w->get_waytype() == wt  ) {
+		// same waytype, check direction
+		if(  w->get_waytype() == wt   &&  ribi_check(ribi, check_ribi ) ) {
 			// ok too
 			return NULL;
 		}
@@ -238,7 +238,7 @@ const char *check_tile( const grund_t *gr, const player_t *player, waytype_t wt,
 			return err_msg;
 		}
 	}
-	return "";	// could end here but must not end here
+	return "";	// could end here but need not end here
 }
 
 bool bridge_builder_t::is_blocked(koord3d pos, ribi_t::ribi check_ribi, const char *&error_msg)
@@ -1077,7 +1077,7 @@ const char *bridge_builder_t::remove(player_t *player, koord3d pos_start, waytyp
 			delete p;
 		}
 		// refresh map
-		reliefkarte_t::get_karte()->calc_map_pixel(pos.get_2d());
+		minimap_t::get_instance()->calc_map_pixel(pos.get_2d());
 	}
 
 	// finally delete the bridge ends (all are kartenboden)
