@@ -87,11 +87,17 @@ void cbuffer_t::append(const char* text, size_t maxchars)
 
 void cbuffer_t::append(double n,int decimals)
 {
-	char tmp[32];
+	char tmp[128];
 	number_to_string( tmp, n, decimals );
 	append(tmp);
 }
 
+void cbuffer_t::append_money(double money)
+{
+	char tmp[128];
+	money_to_string(tmp, money, true);
+	append(tmp);
+}
 
 const char* cbuffer_t::get_str() const
 {
@@ -173,7 +179,7 @@ static void get_format_mask(const char* format, char *typemask, int max_params,
 		for(uint16 i=0; i<found; i++) {
 			if (typemask[i]==0) {
 				// unspecified
-				error.printf("Positional parameter %d not specified.", i+1);
+				error.printf("Positional parameter %d not specified.", i);
 				return;
 			}
 		}
@@ -259,7 +265,7 @@ static int my_vsnprintf(char *buf, size_t n, const char* fmt, va_list ap )
 	if(  const char *c=strstr( fmt, "%1$" )  ) {
 		// but they are requested here ...
 		// our routine can only handle max. 9 parameters
-		char pos[6];
+		char pos[14];
 		static char format_string[256];
 		char *cfmt = format_string;
 		static char buffer[16000];	// the longest possible buffer ...
@@ -349,12 +355,17 @@ void cbuffer_t::vprintf(const char *fmt, va_list ap )
 		size_t inc;
 
 		va_list args;
-#ifdef __va_copy
+
+#if defined(va_copy)
+		va_copy(args, ap);
+#elif defined(__va_copy)
+		// Deprecated macro possibly used by older compilers.
 		__va_copy(args, ap);
 #else
-		// HACK: this is undefined behavior but should work ... hopefully ...
-		args = ap;
+		// Undefined behaviour that might work.
+		args = ap; // If this throws an error then C++11 conformance may be required.
 #endif
+
 		const int count = my_vsnprintf( buf+size, n, fmt, args );
 		if(  count < 0  ) {
 #ifdef _WIN32
@@ -374,6 +385,8 @@ void cbuffer_t::vprintf(const char *fmt, va_list ap )
 			inc = (size_t)count;
 		}
 		extend(inc);
+
+		va_end(args);
 	}
 }
 
