@@ -7,7 +7,7 @@
 #define gui_chart_h
 
 #include "../../simtypes.h"
-#include "gui_komponente.h"
+#include "gui_component.h"
 #include "../../tpl/slist_tpl.h"
 
 // CURVE TYPES
@@ -34,7 +34,7 @@ public:
 	 * paint chart
 	 * @author hsiegeln
 	 */
-	void draw(scr_coord offset);
+	void draw(scr_coord offset) OVERRIDE;
 
 	bool infowin_event(event_t const*) OVERRIDE;
 
@@ -91,6 +91,11 @@ public:
 
 	int get_curve_count() { return curves.get_count(); }
 
+	scr_size get_max_size() const OVERRIDE;
+
+	scr_size get_min_size() const OVERRIDE;
+
+	void set_min_size(scr_size);
 private:
 	void calc_gui_chart_values(sint64 *baseline, float *scale, char *, char *, int precision ) const;
 
@@ -127,6 +132,9 @@ private:
 	 * @author Hj. Malthaner
 	 */
 	FLAGGED_PIXVAL background;
+
+	// TODO do something smarter here
+	scr_size min_size;
 };
 
 #endif
