@@ -21,6 +21,8 @@
 #include "gui_button.h"
 
 
+class loadsave_t;
+
 class gui_combobox_t :
 	public gui_action_creator_t,
 	public gui_component_t,
@@ -41,7 +43,7 @@ private:
 	 * @author hsiegeln
 	 */
 	gui_scrolled_list_t droplist;
-	bool opened_at_bottom:1;
+	bool opened_above:1;
 
 	// flag for first call
 	bool first_call:1;
@@ -52,6 +54,8 @@ private:
 	// true to allow buttons to wrap around selection
 	bool wrapping:1;
 
+	// offset of last draw call, needed to decide, where to open droplist
+	scr_coord last_draw_offset;
 	/**
 	 * the max size this component can have
 	 * @author hsiegeln
@@ -69,38 +73,37 @@ private:
 	void reset_selected_item_name();
 
 public:
-	gui_combobox_t();
+	gui_combobox_t(gui_scrolled_list_t::item_compare_func cmp = 0);
 
 	bool infowin_event(event_t const*) OVERRIDE;
 
 	bool action_triggered(gui_action_creator_t*, value_t) OVERRIDE;
 
-	void sort( int offset, void *sort_param ) { droplist.sort( offset, sort_param ); }
+	void sort( int offset ) { droplist.sort( offset ); }
 
 	/**
 	 * returns the element that has focus.
 	 * child classes like scrolled list of tabs should
 	 * return a child component.
 	 */
-	virtual gui_component_t *get_focus() { return this; }
+	gui_component_t *get_focus() OVERRIDE { return this; }
 
 	/**
 	 * Draw the component
 	 * @author Hj. Malthaner
 	 */
-	void draw(scr_coord offset);
+	void draw(scr_coord offset) OVERRIDE;
 
 	/**
 	 * add element to droplist
 	 * @author hsiegeln
 	 */
-	void append_element( gui_scrolled_list_t::scrollitem_t *item ) { droplist.append_element( item ); set_max_size( max_size ); }
-
-	/**
-	 * add insert to droplist
-	 * @author hsiegeln
-	 */
-	void insert_element( gui_scrolled_list_t::scrollitem_t *item ) { droplist.insert_element( item ); set_max_size( max_size ); }
+	template<class C>
+	void new_component() { droplist.new_component<C>(); }
+	template<class C, class A1>
+	void new_component(const A1& a1) { droplist.new_component<C>(a1); }
+	template<class C, class A1, class A2>
+	void new_component(const A1& a1, const A2& a2) { droplist.new_component<C>(a1, a2); }
 
 	/**
 	 * remove all elements from droplist
@@ -120,12 +123,6 @@ public:
 	 */
 	gui_scrolled_list_t::scrollitem_t *get_element(sint32 idx) const { return droplist.get_element(idx); }
 
-	/**
-	 * sets the highlight color for the droplist
-	 * @author hsiegeln
-	 */
-	void set_highlight_color(PIXVAL color) { droplist.set_highlight_color(color); }
-
 	/**
 	 * set maximum size for control
 	 * @author hsiegeln
@@ -138,6 +135,7 @@ public:
 	 */
 	int get_selection() { return droplist.get_selection(); }
 
+	gui_scrolled_list_t::scrollitem_t* get_selected_item() const { return droplist.get_selected_item(); }
 	/**
 	 * sets the selection
 	 * @author hsiegeln
@@ -148,7 +146,7 @@ public:
 	* Set this component's position.
 	* @author Hj. Malthaner
 	*/
-	virtual void set_pos(scr_coord pos_par);
+	void set_pos(scr_coord pos_par) OVERRIDE;
 
 	void set_size(scr_size size) OVERRIDE;
 
@@ -162,6 +160,16 @@ public:
 	void set_wrapping(const bool wrap) { wrapping = wrap; }
 
 	bool is_dropped() const { return droplist.is_visible(); }
+
+	scr_size get_min_size() const OVERRIDE;
+
+	scr_size get_max_size() const OVERRIDE;
+
+	void enable();
+	void disable();
+
+	// save selection
+	void rdwr( loadsave_t *file );
 };
 
 #endif
