@@ -19,13 +19,13 @@
 
 #include "../../simdebug.h"
 #include "../../simevent.h"
-#include "../../tpl/slist_tpl.h"
-#include "gui_komponente.h"
+#include "../../tpl/vector_tpl.h"
+#include "gui_component.h"
 
-class gui_container_t : public gui_component_t
+class gui_container_t : virtual public gui_component_t
 {
-private:
-	slist_tpl <gui_component_t *> components;
+protected:
+	vector_tpl <gui_component_t *> components;
 
 	// holds the GUI component that has the focus in this window
 	// focused component of this container can only be one of its immediate children
@@ -38,27 +38,22 @@ private:
 
 public:
 	gui_container_t();
+	virtual ~gui_container_t() {}
 
 	// needed for WIN_OPEN events
 	void clear_dirty() { list_dirty=false; }
 
-	/**
-	 * Returns the minimum rectangle which encloses all children
-	 * @author Max Kielland
-	 */
-	scr_rect get_min_boundaries() const;
-
 	/**
 	* Adds a Component to the Container.
 	* @author Hj. Malthaner
 	*/
-	void add_component(gui_component_t *comp);
+	virtual void add_component(gui_component_t *comp);
 
 	/**
 	* Removes a Component in the Container.
 	* @author Hj. Malthaner
 	*/
-	void remove_component(gui_component_t *comp);
+	virtual void remove_component(gui_component_t *comp);
 
 	bool infowin_event(event_t const*) OVERRIDE;
 
@@ -66,19 +61,19 @@ public:
 	* Draw the component
 	* @author Hj. Malthaner
 	*/
-	virtual void draw(scr_coord offset);
+	void draw(scr_coord offset) OVERRIDE;
 
 	/**
 	* Removes all Components in the Container.
 	* @author Markus Weber
 	*/
-	void remove_all();
+	virtual void remove_all();
 
 	/**
 	 * Returns true if any child component is focusable
 	 * @author Knightly
 	 */
-	virtual bool is_focusable();
+	bool is_focusable() OVERRIDE;
 
 	/**
 	 * Activates this element.
@@ -93,14 +88,19 @@ public:
 	 * returns element that has the focus
 	 * that is: go down the hierarchy as much as possible
 	 */
-	virtual gui_component_t *get_focus();
+	gui_component_t *get_focus() OVERRIDE;
 
 	/**
 	 * Get the relative position of the focused component.
 	 * Used for auto-scrolling inside a scroll pane.
 	 * @author Knightly
 	 */
-	virtual scr_coord get_focus_pos() { return comp_focus ? pos+comp_focus->get_focus_pos() : scr_coord::invalid; }
+	scr_coord get_focus_pos() OVERRIDE { return comp_focus ? pos+comp_focus->get_focus_pos() : scr_coord::invalid; }
+
+
+	// FIXME
+	scr_size get_min_size() const OVERRIDE { return get_size(); }
+	scr_size get_max_size() const OVERRIDE { return get_size(); }
 };
 
 #endif
