@@ -9,11 +9,8 @@
 #ifndef gui_components_gui_divider_h
 #define gui_components_gui_divider_h
 
-#include "gui_komponente.h"
-#include "../../display/simgraph.h"
-#include "../../simskin.h"
-
-class skinverwaltung_t;
+#include "gui_component.h"
+#include "../gui_theme.h"
 
 /**
  * A horizontal divider line
@@ -24,21 +21,17 @@ class skinverwaltung_t;
 class gui_divider_t : public gui_component_t
 {
 public:
-	gui_divider_t() { size.h = D_DIVIDER_HEIGHT; }
-
+	// TODO remove later
 	void init( scr_coord xy, scr_coord_val width, scr_coord_val height = D_DIVIDER_HEIGHT ) {
 		set_pos( xy );
 		set_size( scr_size( width, height ) );
 	};
 
-	void set_width(scr_coord_val width) { set_size(scr_size(width, size.h)); }
+	scr_size get_min_size() const OVERRIDE;
 
-	scr_size get_size() const { return scr_size(size.w,max(size.h, D_DIVIDER_HEIGHT)); }
+	scr_size get_max_size() const OVERRIDE;
 
-	void draw(scr_coord offset)
-	{
-		display_img_stretch( gui_theme_t::divider, scr_rect( get_pos()+offset, get_size() ) );
-	}
+	void draw(scr_coord offset) OVERRIDE;
 };
 
 #endif
