@@ -8,7 +8,7 @@
 #ifndef gui_fixedwidth_textarea_h
 #define gui_fixedwidth_textarea_h
 
-#include "gui_komponente.h"
+#include "gui_component.h"
 #include "gui_container.h"
 #include "../../display/simgraph.h"
 
@@ -33,7 +33,7 @@ private:
 	/**
 	 * For calculating text height and/or displaying the text.
 	 */
-	scr_size calc_display_text(const scr_coord offset, const bool draw);
+	scr_size calc_display_text(const scr_coord offset, const bool draw) const;
 
 public:
 	gui_fixedwidth_textarea_t(cbuffer_t* buf, const sint16 width);
@@ -41,14 +41,18 @@ public:
 	void recalc_size();
 
 	// after using any of these setter functions, remember to call recalc_size() to recalculate textarea height
-	void set_width(const sint16 width);
+	void set_width(scr_coord_val width) OVERRIDE;
 
 	void set_reserved_area(const scr_size area);
 
 	// it will deliberately ignore the y-component (height) of the size
 	void set_size(scr_size size) OVERRIDE;
 
-	virtual void draw(scr_coord offset);
+	void draw(scr_coord offset) OVERRIDE;
+
+	scr_size get_min_size() const OVERRIDE;
+
+	scr_size get_max_size() const OVERRIDE;
 };
 
 #endif
