@@ -14,7 +14,7 @@ private:
 	obj_t const *obj; /**< The object to display */
 
 protected:
-	koord3d get_location();
+	koord3d get_location() OVERRIDE;
 
 public:
 	obj_view_t(scr_size const size) :
@@ -26,7 +26,7 @@ public:
 
 	void set_obj( obj_t const *d ) { obj = d; }
 
-	void draw(scr_coord offset) { internal_draw(offset, obj); }
+	void draw(scr_coord offset) OVERRIDE { internal_draw(offset, obj); }
 
 	/**
 	 * resize window in response to a resize event
