@@ -15,7 +15,7 @@
 #include "../../simevent.h"
 #include "../../display/simgraph.h"
 #include "../../simcolor.h"
-#include "../../gui/simwin.h"
+#include "../simwin.h"
 
 #include "../../descriptor/skin_desc.h"
 
@@ -50,24 +50,41 @@ void gui_tab_panel_t::set_size(scr_size size)
 {
 	gui_component_t::set_size(size);
 
-	required_size = scr_size( 8, D_TAB_HEADER_HEIGHT );
+	required_size = scr_size( 8, required_size.h );
 	FOR(slist_tpl<tab>, & i, tabs) {
 		i.x_offset = required_size.w - 4;
 		i.width             = 8 + (i.title ? proportional_string_width(i.title) : IMG_WIDTH);
 		required_size.w += i.width;
-		i.component->set_pos(scr_coord(0, D_TAB_HEADER_HEIGHT));
-		i.component->set_size(get_size() - scr_size(0, D_TAB_HEADER_HEIGHT));
+		if (i.title) {
+			required_size.h = max(required_size.h, LINESPACE + D_V_SPACE);
+		}
+		i.component->set_pos(scr_coord(0, required_size.h));
+		i.component->set_size(get_size() - scr_size(0, required_size.h));
 	}
 
 	if(  required_size.w > size.w  ||  offset_tab > 0  ) {
 		left.set_pos( scr_coord( 0, 0 ) );
-		left.set_size( scr_size( D_ARROW_LEFT_WIDTH, D_TAB_HEADER_HEIGHT ) );
+		left.set_size( scr_size( D_ARROW_LEFT_WIDTH, required_size.h ) );
 		right.set_pos( scr_coord( size.w-D_ARROW_RIGHT_WIDTH, 0 ) );
-		right.set_size( scr_size( D_ARROW_RIGHT_WIDTH, D_TAB_HEADER_HEIGHT ) );
+		right.set_size( scr_size( D_ARROW_RIGHT_WIDTH, required_size.h ) );
 	}
 }
 
 
+scr_size gui_tab_panel_t::get_min_size() const
+{
+	scr_size t_size(0, required_size.h);
+	scr_size c_size(0, 0);
+	FOR(slist_tpl<tab>, const& iter, tabs) {
+		if (iter.title) {
+			t_size.h = max(t_size.h, LINESPACE + D_V_SPACE);
+		}
+		c_size.clip_lefttop( iter.component->get_min_size() );
+	}
+	return t_size + c_size;
+}
+
+
 bool gui_tab_panel_t::action_triggered(gui_action_creator_t *comp, value_t)
 {
 	if(  comp == &right  ) {
@@ -96,7 +113,7 @@ bool gui_tab_panel_t::infowin_event(const event_t *ev)
 		}
 	}
 
-	if(  IS_LEFTRELEASE(ev)  &&  (ev->my > 0  &&  ev->my < D_TAB_HEADER_HEIGHT-1)  )  {
+	if(  IS_LEFTRELEASE(ev)  &&  (ev->my > 0  &&  ev->my < required_size.h-1)  )  {
 		// tab selector was hit
 		int text_x = required_size.w>size.w ? 14 : 4;
 		int k=0;
@@ -150,16 +167,16 @@ void gui_tab_panel_t::draw(scr_coord parent_pos)
 	if(  required_size.w>size.w  ||  offset_tab > 0) {
 		left.draw( parent_pos+pos );
 		right.draw( parent_pos+pos );
-		//display_fillbox_wh_clip_rgb(xpos, ypos+D_TAB_HEADER_HEIGHT-1, 10, 1, SYSCOL_TEXT_HIGHLIGHT, true);
-		display_fillbox_wh_clip_rgb(xpos, ypos+D_TAB_HEADER_HEIGHT-1, D_ARROW_LEFT_WIDTH, 1, SYSCOL_HIGHLIGHT, true);
+		//display_fillbox_wh_clip_rgb(xpos, ypos+required_size.h-1, 10, 1, SYSCOL_TEXT_HIGHLIGHT, true);
+		display_fillbox_wh_clip_rgb(xpos, ypos+required_size.h-1, D_ARROW_LEFT_WIDTH, 1, SYSCOL_HIGHLIGHT, true);
 		xpos += D_ARROW_LEFT_WIDTH;
 	}
 
 	int text_x = xpos + 8;
-	int text_y = ypos + (D_TAB_HEADER_HEIGHT - LINESPACE)/2;
+	int text_y = ypos + (required_size.h - LINESPACE)/2;
 
-	//display_fillbox_wh_clip_rgb(xpos, ypos+D_TAB_HEADER_HEIGHT-1, 4, 1, color_idx_to_rgb(COL_WHITE), true);
-	display_fillbox_wh_clip_rgb(xpos, ypos+D_TAB_HEADER_HEIGHT-1, 4, 1, SYSCOL_HIGHLIGHT, true);
+	//display_fillbox_wh_clip_rgb(xpos, ypos+required_size.h-1, 4, 1, color_idx_to_rgb(COL_WHITE), true);
+	display_fillbox_wh_clip_rgb(xpos, ypos+required_size.h-1, 4, 1, SYSCOL_HIGHLIGHT, true);
 
 	// do not draw under right button
 	int xx = required_size.w>get_size().w ? get_size().w-(D_ARROW_LEFT_WIDTH+2+D_ARROW_RIGHT_WIDTH) : get_size().w;
@@ -172,7 +189,7 @@ void gui_tab_panel_t::draw(scr_coord parent_pos)
 		}
 		if(i>=offset_tab) {
 			// set clipping
-			PUSH_CLIP(xpos, ypos, xx, D_TAB_HEADER_HEIGHT);
+			PUSH_CLIP_FIT(xpos, ypos, xx, required_size.h);
 			// only start drawing here ...
 			char const* const text = iter.title;
 			const int width = text ? proportional_string_width( text ) : IMG_WIDTH;
@@ -180,10 +197,10 @@ void gui_tab_panel_t::draw(scr_coord parent_pos)
 			if (i != active_tab) {
 				// Non active tabs
 				display_fillbox_wh_clip_rgb(text_x-3, ypos+2, width+6, 1, SYSCOL_HIGHLIGHT, true);
-				display_fillbox_wh_clip_rgb(text_x-4, ypos+D_TAB_HEADER_HEIGHT-1, width+8, 1, SYSCOL_HIGHLIGHT, true);
+				display_fillbox_wh_clip_rgb(text_x-4, ypos+required_size.h-1, width+8, 1, SYSCOL_HIGHLIGHT, true);
 
-				display_vline_wh_clip_rgb(text_x-4, ypos+3, D_TAB_HEADER_HEIGHT-4, SYSCOL_HIGHLIGHT, true);
-				display_vline_wh_clip_rgb(text_x+width+3, ypos+3, D_TAB_HEADER_HEIGHT-4, SYSCOL_SHADOW, true);
+				display_vline_wh_clip_rgb(text_x-4, ypos+3, required_size.h-4, SYSCOL_HIGHLIGHT, true);
+				display_vline_wh_clip_rgb(text_x+width+3, ypos+3, required_size.h-4, SYSCOL_SHADOW, true);
 
 				if(text) {
 					display_proportional_clip_rgb(text_x, text_y, text, ALIGN_LEFT, SYSCOL_TEXT, true);
@@ -198,8 +215,8 @@ void gui_tab_panel_t::draw(scr_coord parent_pos)
 				// Active tab
 				display_fillbox_wh_clip_rgb(text_x-3, ypos, width+6, 1, SYSCOL_HIGHLIGHT, true);
 
-				display_vline_wh_clip_rgb(text_x-4, ypos+1, D_TAB_HEADER_HEIGHT-2, SYSCOL_HIGHLIGHT, true);
-				display_vline_wh_clip_rgb(text_x+width+3, ypos+1, D_TAB_HEADER_HEIGHT-2, SYSCOL_SHADOW, true);
+				display_vline_wh_clip_rgb(text_x-4, ypos+1, required_size.h-2, SYSCOL_HIGHLIGHT, true);
+				display_vline_wh_clip_rgb(text_x+width+3, ypos+1, required_size.h-2, SYSCOL_SHADOW, true);
 
 				if(text) {
 					display_proportional_clip_rgb(text_x, text_y, text, ALIGN_LEFT, SYSCOL_TEXT_HIGHLIGHT, true);
@@ -215,11 +232,11 @@ void gui_tab_panel_t::draw(scr_coord parent_pos)
 			POP_CLIP();
 		}
 	}
-	display_fillbox_wh_clip_rgb(text_x-4, ypos+D_TAB_HEADER_HEIGHT-1, xpos+size.w-(text_x-4), 1, SYSCOL_HIGHLIGHT, true);
+	display_fillbox_wh_clip_rgb(text_x-4, ypos+required_size.h-1, xpos+size.w-(text_x-4), 1, SYSCOL_HIGHLIGHT, true);
 
 	// now for tooltips ...
 	int my = get_mouse_y()-parent_pos.y-pos.y-6;
-	if(my>=0  &&  my < D_TAB_HEADER_HEIGHT-1) {
+	if(my>=0  &&  my < required_size.h-1) {
 		// Reiter getroffen?
 		int mx = get_mouse_x()-parent_pos.x-pos.x-11;
 		int text_x = 4;
@@ -231,7 +248,7 @@ void gui_tab_panel_t::draw(scr_coord parent_pos)
 
 				if(text_x < mx && text_x+width+8 > mx  && (required_size.w<=get_size().w || mx < right.get_pos().x-12)) {
 					// tooltip or change
-					win_set_tooltip(get_mouse_x() + 16, ypos + D_TAB_HEADER_HEIGHT + 12, iter.tooltip, &iter, this);
+					win_set_tooltip(get_mouse_x() + 16, ypos + required_size.h + 12, iter.tooltip, &iter, this);
 					break;
 				}
 
@@ -247,3 +264,19 @@ void gui_tab_panel_t::clear()
 	tabs.clear();
 	active_tab = 0;
 }
+
+
+void gui_tab_panel_t::take_tabs(gui_tab_panel_t* other)
+{
+	tabs.append_list(other->tabs);
+}
+
+
+void gui_tab_panel_t::rdwr( loadsave_t *file )
+{
+	sint32 a = get_active_tab_index();
+	file->rdwr_long(a);
+	if (file->is_loading()) {
+		set_active_tab_index(a);
+	}
+}
