@@ -206,8 +206,8 @@ int compare_crossing(const crossing_desc_t *c0, const crossing_desc_t *c1)
 void crossing_logic_t::register_desc(crossing_desc_t *desc)
 {
 	// mark if crossing possible
-	const waytype_t way0 = (const waytype_t)min(desc->get_waytype(0), desc->get_waytype(1));
-	const waytype_t way1 = (const waytype_t)max(desc->get_waytype(0), desc->get_waytype(1));
+	const waytype_t way0 = (waytype_t)min(desc->get_waytype(0), desc->get_waytype(1));
+	const waytype_t way1 = (waytype_t)max(desc->get_waytype(0), desc->get_waytype(1));
 	if(way0<8  &&  way1<9  &&  way0<way1) {
 		uint8 index = way0 * 9 + way1 - ((way0+2)*(way0+1))/2;
 		// max index = 7*9 + 8 - 9*4 = 71-36 = 35
