@@ -13,9 +13,9 @@
 #ifndef curiositylist_stats_t_h
 #define curiositylist_stats_t_h
 
-#include "../tpl/vector_tpl.h"
-#include "components/gui_komponente.h"
-#include "components/gui_button.h"
+#include "components/gui_aligned_container.h"
+#include "components/gui_colorbox.h"
+#include "components/gui_scrolled_list.h"
 
 class gebaeude_t;
 
@@ -23,33 +23,29 @@ namespace curiositylist {
     enum sort_mode_t { by_name=0, by_paxlevel/*, by_maillevel*/, SORT_MODES };
 };
 
-class curiositylist_stats_t : public gui_world_component_t
+class curiositylist_stats_t : public gui_aligned_container_t, public gui_scrolled_list_t::scrollitem_t
 {
 private:
-	vector_tpl<gebaeude_t*> attractions;
-	uint32 line_selected;
-
-	uint32 last_world_curiosities;
-	curiositylist::sort_mode_t sortby;
-	bool sortreverse;
+	gebaeude_t* attraction;
+	gui_colorbox_t indicator;
 
 public:
-	curiositylist_stats_t(curiositylist::sort_mode_t sortby, bool sortreverse);
+	static curiositylist::sort_mode_t sortby;
+	static bool sortreverse;
+	static bool compare(const gui_component_t *a, const gui_component_t *b );
 
-	void get_unique_attractions(curiositylist::sort_mode_t sortby, bool reverse);
+	curiositylist_stats_t(gebaeude_t *att);
+
+	char const* get_text() const OVERRIDE;
+	bool is_valid() const OVERRIDE;
 
 	bool infowin_event(event_t const*) OVERRIDE;
 
-	/**
-	 * Recalc the size required to display everything and set size (size).
-	 */
-	void recalc_size();
-
 	/**
 	* Draw the component
 	* @author Hj. Malthaner
 	*/
-	void draw(scr_coord offset);
+	void draw(scr_coord offset) OVERRIDE;
 };
 
 #endif
