@@ -25,7 +25,7 @@ class env_t
 {
 public:
 	/// points to the current simutrans data directory
-	static char program_dir[1024];
+	static char program_dir[PATH_MAX];
 
 	/// points to the current user directory for loading and saving
 	static const char *user_dir;
@@ -170,6 +170,9 @@ public:
 	/// default behavior of the map-window
 	static uint32 default_mapmode;
 
+	/// cut through the map when following convois?
+	static uint8 follow_convoi_underground;
+
 	///which messages to display where?
 	/**
 	 * message_flags[i] is bitfield, where bit is set if message should be show at location i,
