@@ -33,7 +33,7 @@
 
 #include "../descriptor/objversion.h"
 
-#include "../gui/karte.h"	// to update map after construction of new industry
+#include "../gui/minimap.h" // to update map after construction of new industry
 
 
 karte_ptr_t factory_builder_t::welt;
@@ -92,7 +92,7 @@ void init_fab_map( karte_t *welt )
 
 
 /**
- * @param x,y world position
+ * @param x,y world position, needs to be valid coordinates
  * @returns true, if factory coordinate
  */
 inline bool is_factory_at( sint16 x, sint16 y)
@@ -118,7 +118,7 @@ class factory_site_searcher_t: public building_placefinder_t  {
 public:
 	factory_site_searcher_t(karte_t* welt, factory_desc_t::site_t site_) : building_placefinder_t(welt), site(site_) {}
 
-	virtual bool is_area_ok(koord pos, sint16 w, sint16 h, climate_bits cl) const
+	bool is_area_ok(koord pos, sint16 w, sint16 h, climate_bits cl) const OVERRIDE
 	{
 		if(  !building_placefinder_t::is_area_ok(pos, w, h, cl)  ) {
 			return false;
@@ -362,7 +362,7 @@ bool factory_builder_t::check_construction_site(koord pos, koord size, factory_d
 		else {
 			// check on land
 			// do not build too close or on an existing factory
-			if( is_factory_at(pos.x, pos.y)  ) {
+			if( !welt->is_within_limits(pos)  || is_factory_at(pos.x, pos.y)  ) {
 				return false;
 			}
 			return welt->square_is_free(pos, size.x, size.y, NULL, cl);
@@ -463,7 +463,7 @@ void factory_builder_t::distribute_attractions(int max_number)
 
 	}
 	// update an open map
-	reliefkarte_t::get_karte()->calc_map_size();
+	minimap_t::get_instance()->calc_map_size();
 }
 
 /**
@@ -717,7 +717,7 @@ int factory_builder_t::build_link(koord3d* parent, const factory_desc_t* info, s
 		DBG_MESSAGE("factory_builder_t::build_link()","update karte");
 
 		// update the map if needed
-		reliefkarte_t::get_karte()->calc_map_size();
+		minimap_t::get_instance()->calc_map_size();
 
 		INT_CHECK( "fabrikbauer 730" );
 
@@ -1012,7 +1012,7 @@ next_ware_check:
 				buf.printf( translator::translate("Factory chain extended\nfor %s near\n%s built with\n%i factories."), translator::translate(last_built_consumer->get_name()), stadt_name, nr );
 				welt->get_message()->add_message(buf, last_built_consumer->get_pos().get_2d(), message_t::industry, CITY_KI, last_built_consumer->get_desc()->get_building()->get_tile(0)->get_background(0, 0, 0));
 			}
-			reliefkarte_t::get_karte()->calc_map();
+			minimap_t::get_instance()->calc_map();
 			return nr;
 		}
 	}
@@ -1065,7 +1065,7 @@ next_ware_check:
 					nr += build_link(NULL, fab, -1 /* random prodbase */, rotation, &pos, welt->get_public_player(), 1, ignore_climates);
 					if(nr>0) {
 						fabrik_t *our_fab = fabrik_t::get_fab( pos.get_2d() );
-						reliefkarte_t::get_karte()->calc_map_size();
+						minimap_t::get_instance()->calc_map_size();
 						// tell the player
 						if(tell_me) {
 							const char *stadt_name = translator::translate("nowhere");
