@@ -19,12 +19,13 @@
 #include "components/action_listener.h"
 #include "components/gui_label.h"
 #include "components/gui_button.h"
+#include "components/gui_button_to_chart.h"
 #include "components/gui_chart.h"
 #include "components/gui_tab_panel.h"
-#include "components/gui_container.h"
+#include "components/gui_aligned_container.h"
+#include "components/gui_button_to_chart.h"
 
-
-class factory_chart_t : public gui_container_t, private action_listener_t
+class factory_chart_t : public gui_aligned_container_t
 {
 private:
 	const fabrik_t *factory;
@@ -33,28 +34,17 @@ private:
 	gui_tab_panel_t tab_panel;
 
 	// GUI components for input/output goods' statistics
-	gui_container_t goods_cont;
+	gui_aligned_container_t goods_cont;
 	gui_chart_t goods_chart;
-	button_t *goods_buttons;
-	gui_label_t *goods_labels;
-	uint16 goods_button_count;
-	uint16 goods_label_count;
 
 	// GUI components for other production-related statistics
-	gui_container_t prod_cont;
+	gui_aligned_container_t prod_cont;
 	gui_chart_t prod_chart;
-	button_t prod_buttons[MAX_FAB_STAT];
-	button_t prod_ref_line_buttons[MAX_FAB_REF_LINE];
-	gui_label_t prod_labels[MAX_PROD_LABEL];
 
 	// Variables for reference lines
 	sint64 prod_ref_line_data[MAX_FAB_REF_LINE];
 
-	struct button_to_curve_t {
-		button_t* button;
-		uint16 curve;
-	};
-	button_to_curve_t button_to_curve[MAX_FAB_STAT+MAX_FAB_REF_LINE];
+	gui_button_to_chart_array_t button_to_chart;
 
 public:
 	factory_chart_t(const fabrik_t *_factory);
@@ -62,11 +52,15 @@ public:
 
 	void set_factory(const fabrik_t *_factory);
 
-	bool action_triggered(gui_action_creator_t*, value_t) OVERRIDE;
-
-	virtual void draw(scr_coord pos);
+	void update();
 
 	void rdwr( loadsave_t *file );
+
+	/**
+	 * factory window will take our tabs,
+	 * we only initialize them and update charts
+	 */
+	gui_tab_panel_t* get_tab_panel() { return &tab_panel; }
 };
 
 #endif
