@@ -27,13 +27,15 @@
 #include "../utils/cbuffer_t.h"
 
 #include "factory_edit.h"
+#include "components/gui_label.h"
 
 
 // new tool definition
 tool_build_land_chain_t factory_edit_frame_t::land_chain_tool = tool_build_land_chain_t();
 tool_city_chain_t factory_edit_frame_t::city_chain_tool = tool_city_chain_t();
 tool_build_factory_t factory_edit_frame_t::fab_tool = tool_build_factory_t();
-char factory_edit_frame_t::param_str[256];
+cbuffer_t factory_edit_frame_t::param_str;
+
 
 static bool compare_fabrik_desc(const factory_desc_t* a, const factory_desc_t* b)
 {
@@ -49,61 +51,36 @@ static bool compare_factory_desc_trans(const factory_desc_t* a, const factory_de
 
 factory_edit_frame_t::factory_edit_frame_t(player_t* player_) :
 	extend_edit_gui_t(translator::translate("factorybuilder"), player_),
-	factory_list(16),
-	lb_rotation( rot_str, SYSCOL_TEXT_HIGHLIGHT, gui_label_t::right ),
-	lb_rotation_info( translator::translate("Rotation"), SYSCOL_TEXT, gui_label_t::left ),
-	lb_production_info( translator::translate("Produktion"), SYSCOL_TEXT, gui_label_t::left )
+	factory_list(16)
 {
-	rot_str[0] = 0;
-	prod_str[0] = 0;
-	land_chain_tool.set_default_param(param_str);
-	city_chain_tool.set_default_param(param_str);
-	fab_tool.set_default_param(param_str);
 	land_chain_tool.cursor = city_chain_tool.cursor = fab_tool.cursor = tool_t::general_tool[TOOL_BUILD_FACTORY]->cursor;
-
 	fac_desc = NULL;
 
-	bt_city_chain.init( button_t::square_state, "Only city chains", scr_coord(get_tab_panel_width()+2*MARGIN, offset_of_comp-4 ) );
+	bt_city_chain.init( button_t::square_state, "Only city chains");
 	bt_city_chain.add_listener(this);
-	add_component(&bt_city_chain);
-	offset_of_comp += D_BUTTON_HEIGHT;
+	cont_right.add_component(&bt_city_chain);
 
-	bt_land_chain.init( button_t::square_state, "Only land chains", scr_coord(get_tab_panel_width()+2*MARGIN, offset_of_comp-4 ) );
+	bt_land_chain.init( button_t::square_state, "Only land chains");
 	bt_land_chain.add_listener(this);
-	add_component(&bt_land_chain);
-	offset_of_comp += D_BUTTON_HEIGHT;
+	cont_right.add_component(&bt_land_chain);
 
-	lb_rotation_info.set_pos( scr_coord( get_tab_panel_width()+2*MARGIN, offset_of_comp-4 ) );
-	add_component(&lb_rotation_info);
+	// rotation, production
+	gui_aligned_container_t *tbl = cont_right.add_table(2,2);
+	tbl->new_component<gui_label_t>("Rotation");
+	tbl->add_component(&cb_rotation);
+	cb_rotation.add_listener(this);
+	cb_rotation.new_component<gui_scrolled_list_t::const_text_scrollitem_t>(translator::translate("random"), SYSCOL_TEXT) ;
 
-	bt_left_rotate.init( button_t::repeatarrowleft, NULL, scr_coord(get_tab_panel_width()+2*MARGIN+COLUMN_WIDTH/2-16,	offset_of_comp-4 ) );
-	bt_left_rotate.add_listener(this);
-	add_component(&bt_left_rotate);
+	tbl->new_component<gui_label_t>("Produktion");
 
-	bt_right_rotate.init( button_t::repeatarrowright, NULL, scr_coord(get_tab_panel_width()+2*MARGIN+COLUMN_WIDTH/2+50-2, offset_of_comp-4 ) );
-	bt_right_rotate.add_listener(this);
-	add_component(&bt_right_rotate);
-
-	//lb_rotation.set_pos( scr_coord( get_tab_panel_width()+2*MARGIN+COLUMN_WIDTH/2+44, offset_of_comp-4 ) );
-	lb_rotation.set_width( bt_right_rotate.get_pos().x - bt_left_rotate.get_pos().x - bt_left_rotate.get_size().w );
-	lb_rotation.align_to(&bt_left_rotate,ALIGN_EXTERIOR_H | ALIGN_LEFT | ALIGN_CENTER_V);
-	add_component(&lb_rotation);
-	offset_of_comp += D_BUTTON_HEIGHT;
-
-	lb_production_info.set_pos( scr_coord( get_tab_panel_width()+2*MARGIN, offset_of_comp-4 ) );
-	add_component(&lb_production_info);
-
-	inp_production.set_pos(scr_coord(get_tab_panel_width()+2*MARGIN+COLUMN_WIDTH/2-16,	offset_of_comp-4-2 ));
-	inp_production.set_size(scr_size( 76, D_EDIT_HEIGHT ));
 	inp_production.set_limits(0,9999);
 	inp_production.add_listener( this );
-	add_component(&inp_production);
-
-	offset_of_comp += D_BUTTON_HEIGHT;
+	tbl->add_component(&inp_production);
+	cont_right.end_table();
 
 	fill_list( is_show_trans_name );
 
-	resize(scr_coord(0,0));
+	reset_min_windowsize();
 }
 
 
@@ -154,53 +131,47 @@ void factory_edit_frame_t::fill_list( bool translate )
 			i->is_producer_only() ? color_idx_to_rgb(COL_DARK_GREEN) :
 			SYSCOL_TEXT;
 		char const* const name = translate ? translator::translate(i->get_name()) : i->get_name();
-		scl.append_element(new gui_scrolled_list_t::const_text_scrollitem_t(name, color));
+		scl.new_component<gui_scrolled_list_t::const_text_scrollitem_t>(name, color);
 		if (i == fac_desc) {
 			scl.set_selection(scl.get_count()-1);
 		}
 	}
 	// always update current selection (since the tool may depend on it)
 	change_item_info( scl.get_selection() );
+
+	reset_min_windowsize();
 }
 
 
 
-bool factory_edit_frame_t::action_triggered( gui_action_creator_t *komp,value_t e)
+bool factory_edit_frame_t::action_triggered( gui_action_creator_t *comp,value_t e)
 {
 	// only one chain can be shown
-	if(  komp==&bt_city_chain  ) {
+	if(  comp==&bt_city_chain  ) {
 		bt_city_chain.pressed ^= 1;
 		if(bt_city_chain.pressed) {
 			bt_land_chain.pressed = 0;
 		}
 		fill_list( is_show_trans_name );
 	}
-	else if(  komp==&bt_land_chain  ) {
+	else if(  comp==&bt_land_chain  ) {
 		bt_land_chain.pressed ^= 1;
 		if(bt_land_chain.pressed) {
 			bt_city_chain.pressed = 0;
 		}
 		fill_list( is_show_trans_name );
 	}
+	else if( comp == &cb_rotation) {
+		change_item_info( scl.get_selection() );
+	}
 	else if(fac_desc) {
-		if (komp==&inp_production) {
+		if (comp==&inp_production) {
 			production = inp_production.get_value();
 		}
-		else if(  komp==&bt_left_rotate  &&  rotation!=255) {
-			if(rotation==0) {
-				rotation = 255;
-			}
-			else {
-				rotation --;
-			}
-		}
-		else if(  komp==&bt_right_rotate  &&  rotation!=fac_desc->get_building()->get_all_layouts()-1) {
-			rotation ++;
-		}
 		// update info ...
 		change_item_info( scl.get_selection() );
 	}
-	return extend_edit_gui_t::action_triggered(komp,e);
+	return extend_edit_gui_t::action_triggered(comp,e);
 }
 
 
@@ -294,79 +265,68 @@ void factory_edit_frame_t::change_item_info(sint32 entry)
 				buf.printf(translator::translate("Constructed by %s"), maker);
 			}
 			buf.append("\n");
-			info_text.recalc_size();
-			cont.set_size( info_text.get_size() + scr_size(0, 20) );
+
+			// reset combobox
+			cb_rotation.clear_elements();
+			cb_rotation.new_component<gui_rotation_item_t>(gui_rotation_item_t::random);
+			for(uint8 i = 0; i<desc->get_all_layouts(); i++) {
+				cb_rotation.new_component<gui_rotation_item_t>(i);
+			}
 
 			// orientation (255=random)
 			if(desc->get_all_layouts()>1) {
-				rotation = 255; // no definition yet
+				cb_rotation.set_selection(0);
 			}
 			else {
-				rotation = 0;
+				cb_rotation.set_selection(1);
 			}
 
 			// now for the tool
 			fac_desc = factory_list[entry];
 		}
 
-		// change label numbers
-		if(rotation == 255) {
-			tstrncpy(rot_str, translator::translate("random"), lengthof(rot_str));
-		}
-		else {
-			sprintf( rot_str, "%i", rotation );
-		}
-
-		// now the images (maximum is 2x2 size)
-		// since these may be affected by rotation, we do this every time ...
-		for(int i=0;  i<4;  i++  ) {
-			img[i].set_image( IMG_EMPTY );
-		}
-
 		const building_desc_t *desc = fac_desc->get_building();
+		uint8 rotation = get_rotation();
 		uint8 rot = (rotation==255) ? 0 : rotation;
-		if(desc->get_x(rot)==1) {
-			if(desc->get_y(rot)==1) {
-				img[3].set_image( desc->get_tile(rot,0,0)->get_background(0,0,0) );
-			}
-			else {
-				img[2].set_image( desc->get_tile(rot,0,0)->get_background(0,0,0) );
-				img[3].set_image( desc->get_tile(rot,0,1)->get_background(0,0,0) );
-			}
-		}
-		else {
-			if(desc->get_y(rot)==1) {
-				img[1].set_image( desc->get_tile(rot,0,0)->get_background(0,0,0) );
-				img[3].set_image( desc->get_tile(rot,1,0)->get_background(0,0,0) );
-			}
-			else {
-				// maximum 2x2 image
-				for(int i=0;  i<4;  i++  ) {
-					img[i].set_image( desc->get_tile(rot,i/2,i&1)->get_background(0,0,0) );
-				}
-			}
-		}
+		building_image.init(desc, rot);
 
 		// the tools will be always updated, even though the data up there might be still current
-		sprintf( param_str, "%i%c%i,%s", bt_climates.pressed, rotation==255 ? '#' : '0'+rotation, production, fac_desc->get_name() );
+		param_str.clear();
+		param_str.printf("%i%c%i,%s", bt_climates.pressed, rotation==255 ? '#' : '0'+rotation, production, fac_desc->get_name() );
 		if(bt_land_chain.pressed) {
+			land_chain_tool.set_default_param(param_str);
 			welt->set_tool( &land_chain_tool, player );
 		}
 		else if(bt_city_chain.pressed) {
+			city_chain_tool.set_default_param(param_str);
 			welt->set_tool( &city_chain_tool, player );
 		}
 		else {
+			fab_tool.set_default_param(param_str);
 			welt->set_tool( &fab_tool, player );
 		}
 	}
 	else if(fac_desc!=NULL) {
-		for(int i=0;  i<4;  i++  ) {
-			img[i].set_image( IMG_EMPTY );
-		}
-		buf.clear();
-		prod_str[0] = 0;
-		tstrncpy(rot_str, translator::translate("random"), lengthof(rot_str));
+		cb_rotation.clear_elements();
+		cb_rotation.new_component<gui_rotation_item_t>(gui_rotation_item_t::random);
+
+		building_image.init(NULL, 0);
 		fac_desc = NULL;
 		welt->set_tool( tool_t::general_tool[TOOL_QUERY], player );
 	}
+	info_text.recalc_size();
+	reset_min_windowsize();
+}
+
+
+void factory_edit_frame_t::set_windowsize(scr_size size)
+{
+	extend_edit_gui_t::set_windowsize(size);
+
+	// manually set width of cb_rotation and inp_production
+	scr_size cbs = cb_rotation.get_size();
+	scr_size nis = inp_production.get_size();
+	scr_coord_val w = max(cbs.w, nis.w);
+	cb_rotation.set_size(scr_size(w, cbs.h));
+	inp_production.set_size(scr_size(w, nis.h));
 }
