@@ -18,30 +18,27 @@ class factorylist_frame_t : public gui_frame_t, private action_listener_t
 private:
 	static const char *sort_text[factorylist::SORT_MODES];
 
-	gui_label_t sort_label;
 	button_t	sortedby;
 	button_t	sorteddir;
 	gui_scrolled_list_t scrolly;
 
+	void fill_list();
+
 public:
 	factorylist_frame_t();
 
-	/**
-	 * resize window in response to a resize event
-	 * @author Hj. Malthaner
-	 */
-	void resize(const scr_coord delta);
-
 	/**
 	 * Set the window associated helptext
 	 * @return the filename for the helptext, or NULL
 	 * @author V. Meyer
 	 */
-	const char * get_help_filename() const {return "factorylist_filter.txt"; }
+	const char * get_help_filename() const OVERRIDE {return "factorylist_filter.txt"; }
 
 	bool action_triggered(gui_action_creator_t*, value_t) OVERRIDE;
 
-	void draw(scr_coord pos, scr_size size);
+	void draw(scr_coord pos, scr_size size) OVERRIDE;
+
+	bool has_min_sizer() const { return true; }
 };
 
 #endif
