@@ -12,11 +12,12 @@
 #ifndef factorylist_stats_t_h
 #define factorylist_stats_t_h
 
+#include "components/gui_colorbox.h"
+#include "components/gui_image.h"
+#include "components/gui_label.h"
 #include "components/gui_scrolled_list.h"
-#include "../display/simgraph.h"
 #include "../simfab.h"
 
-class karte_ptr_t;
 class fabrik_t;
 
 
@@ -28,30 +29,29 @@ namespace factorylist {
  * Factory list stats display
  * @author Hj. Malthaner
  */
-// City list stats display
-class factorylist_stats_t : public gui_scrolled_list_t::scrollitem_t
+class factorylist_stats_t : public gui_aligned_container_t, public gui_scrolled_list_t::scrollitem_t
 {
 private:
 	fabrik_t *fab;
-	bool mouse_over;  // flag to remember, whether last pressed mouse button on this
-
-	static scr_coord_val h;
-
-	static bool compare( gui_scrolled_list_t::scrollitem_t *a, gui_scrolled_list_t::scrollitem_t *b );
+	gui_colorbox_t indicator;
+	gui_image_t boost_electric, boost_passenger, boost_mail;
+	gui_label_buf_t label;
 
+	void update_label();
 public:
 	static int sort_mode;
 	static bool reverse;
 
-public:
 	factorylist_stats_t(fabrik_t *);
 
-	scr_coord_val get_height() const { return h; }
+	void draw( scr_coord pos) OVERRIDE;
 
-	scr_coord_val draw( scr_coord pos, scr_coord_val width, bool is_selected, bool has_focus );
-	char const* get_text() const { return fab->get_name(); }
-	bool sort( vector_tpl<scrollitem_t *> &, int, void * ) const;
-	bool infowin_event(const event_t *);
+	char const* get_text() const OVERRIDE { return fab->get_name(); }
+	bool infowin_event(const event_t *) OVERRIDE;
+	bool is_valid() const OVERRIDE;
+	void set_size(scr_size size) OVERRIDE;
+
+	static bool compare(const gui_component_t *a, const gui_component_t *b );
 };
 
 
