@@ -31,6 +31,7 @@
 #include "../dataobj/environment.h"
 
 #include "../obj/baum.h"
+#include "../obj/bruecke.h"
 #include "../obj/crossing.h"
 #include "../obj/groundobj.h"
 #include "../obj/label.h"
@@ -41,7 +42,7 @@
 #include "../obj/wayobj.h"
 
 #include "../gui/ground_info.h"
-#include "../gui/karte.h"
+#include "../gui/minimap.h"
 
 #include "../tpl/inthashtable_tpl.h"
 
@@ -187,11 +188,11 @@ void grund_t::rdwr(loadsave_t *file)
 	uint8 climate_data = plan->get_climate() + (plan->get_climate_corners() << 4);
 
 	xml_tag_t g( file, "grund_t" );
-	if(file->get_version()<101000) {
+	if(file->is_version_less(101, 0)) {
 		pos.rdwr(file);
 		z_w = welt->get_groundwater();
 	}
-	else if(  file->get_version() < 112007  ) {
+	else if(  file->is_version_less(112, 7)  ) {
 		file->rdwr_byte(z);
 		pos.z = get_typ() == grund_t::wasser ? welt->get_groundwater() : z;
 		z_w = welt->get_groundwater();
@@ -212,7 +213,7 @@ void grund_t::rdwr(loadsave_t *file)
 		plan->set_climate_corners((climate_data >> 4));
 	}
 
-	if(  file->is_loading()  &&  file->get_version() < 112007  ) {
+	if(  file->is_loading()  &&  file->is_version_less(112, 7)  ) {
 		// convert heights from old single height saved game - water already at correct height
 		pos.z = get_typ() == grund_t::wasser ? pos.z : pos.z * env_t::pak_height_conversion_factor;
 		z = z * env_t::pak_height_conversion_factor;
@@ -231,7 +232,7 @@ void grund_t::rdwr(loadsave_t *file)
 		}
 	}
 
-	if(file->get_version()<99007) {
+	if(file->is_version_less(99, 7)) {
 		bool label;
 		file->rdwr_bool(label);
 		if(label) {
@@ -240,13 +241,13 @@ void grund_t::rdwr(loadsave_t *file)
 	}
 
 	sint8 owner_n=-1;
-	if(file->get_version()<99005) {
+	if(file->is_version_less(99, 5)) {
 		file->rdwr_byte(owner_n);
 	}
 
-	if(file->get_version()>=88009) {
+	if(file->is_version_atleast(88, 9)) {
 		uint8 sl = slope;
-		if(  file->get_version() < 112007  &&  file->is_saving()  ) {
+		if(  file->is_version_less(112, 7)  &&  file->is_saving()  ) {
 			// truncate double slopes to single slopes, better than nothing
 			sl = min( corner_sw(slope), 1 ) + min( corner_se(slope), 1 ) * 2 + min( corner_ne(slope), 1 ) * 4 + min( corner_nw(slope), 1 ) * 8;
 		}
@@ -261,7 +262,7 @@ void grund_t::rdwr(loadsave_t *file)
 	}
 
 	if(  file->is_loading()  ) {
-		if(  file->get_version() < 112007  ) {
+		if(  file->is_version_less(112, 7)  ) {
 			// convert slopes from old single height saved game
 			slope = (scorner_sw(slope) + scorner_se(slope) * 3 + scorner_ne(slope) * 9 + scorner_nw(slope) * 27) * env_t::pak_height_conversion_factor;
 		}
@@ -376,7 +377,7 @@ void grund_t::rdwr(loadsave_t *file)
 
 					case water_wt:
 						// ignore old type dock ...
-						if(file->get_version()>=87000) {
+						if(file->is_version_atleast(87, 0)) {
 							weg = new kanal_t(file);
 						}
 						else {
@@ -574,13 +575,6 @@ void grund_t::take_obj_from(grund_t* other_gr)
 
 void grund_t::open_info_window()
 {
-	int old_count = win_get_open_count();
-	if(get_halt().is_bound()) {
-		get_halt()->open_info_window();
-		if(env_t::single_info  &&  old_count!=win_get_open_count()  ) {
-			return;
-		}
-	}
 	if(env_t::ground_info  ||  hat_wege()) {
 		create_win(new grund_info_t(this), w_info, (ptrdiff_t)this);
 	}
@@ -597,7 +591,24 @@ void grund_t::info(cbuffer_t& buf) const
 				buf.append("\n");
 			}
 			obj_bei(0)->info(buf);
+			// creator of bridge or tunnel graphic
+			const char* maker = NULL;
+			if (ist_tunnel()) {
+				if (tunnel_t* tunnel = find<tunnel_t>(1)) {
+					maker = tunnel->get_desc()->get_copyright();
+				}
+			}
+			if (ist_bruecke()) {
+				if (bruecke_t* bridge = find<bruecke_t>(1)) {
+					maker = bridge->get_desc()->get_copyright();
+				}
+			}
+			if (maker) {
+				buf.printf(translator::translate("Constructed by %s"), maker);
+				buf.append("\n");
+			}
 			buf.append("\n");
+			// second way
 			if(flags&has_way2) {
 				buf.append(translator::translate(get_weg_nr(1)->get_name()));
 				buf.append("\n");
@@ -605,10 +616,7 @@ void grund_t::info(cbuffer_t& buf) const
 				buf.append("\n");
 				if(ist_uebergang()) {
 					crossing_t* crossing = find<crossing_t>(2);
-					buf.append(translator::translate(crossing->get_name()));
-					buf.append("\n");
-					crossing->get_logic()->info(buf);
-					buf.append("\n");
+					crossing->info(buf);
 				}
 			}
 		}
@@ -1091,7 +1099,7 @@ void grund_t::display_boden(const sint16 xpos, const sint16 ypos, const sint16 r
 					// finally overlay any water transition
 					if(  water_corners  ) {
 						if(  slope  ) {
-							display_alpha( ground_desc_t::get_water_tile(slope), ground_desc_t::get_beach_tile( slope, water_corners ), ALPHA_RED, xpos, ypos, 0, 0, true, dirty CLIP_NUM_PAR );
+							display_alpha( ground_desc_t::get_water_tile(slope, wasser_t::stage), ground_desc_t::get_beach_tile( slope, water_corners ), ALPHA_RED, xpos, ypos, 0, 0, true, dirty|wasser_t::change_stage CLIP_NUM_PAR );
 							if(  ground_desc_t::shore  ) {
 								// additional shore image
 								image_id shore = ground_desc_t::shore->get_image(slope,snow_transition<=0);
@@ -1245,7 +1253,7 @@ void grund_t::display_if_visible(sint16 xpos, sint16 ypos, const sint16 raster_t
 {
 	if(  !is_karten_boden_visible()  ) {
 		// only check for forced redraw (of marked ... )
-		if(dirty) {
+		if(  get_flag(grund_t::dirty)  ) {
 			mark_rect_dirty_clip( xpos, ypos + raster_tile_width / 2, xpos + raster_tile_width - 1, ypos + raster_tile_width - 1 CLIP_NUM_PAR );
 		}
 		return;
@@ -1404,7 +1412,7 @@ void grund_t::display_obj_all(const sint16 xpos, const sint16 ypos, const sint16
 		}
 	}
 	else if (is_water()) {
-		ribi = (static_cast<const wasser_t*>(this))->get_weg_ribi(water_wt);
+		ribi = (static_cast<const wasser_t*>(this))->get_display_ribi();
 	}
 
 	// no ways? - no clipping needed, avoid all the ribi-checks
@@ -1666,7 +1674,7 @@ void grund_t::display_overlay(const sint16 xpos, const sint16 ypos)
 					display_outline_proportional_rgb( new_xpos, ypos-(LINESPACE/2), pc+3, color_idx_to_rgb(COL_BLACK), text, dirty );
 					break;
 				case 2:
-					display_outline_proportional_rgb( 16+new_xpos, ypos-(LINESPACE/2), color_idx_to_rgb(COL_YELLOW), color_idx_to_rgb(COL_BLACK), text, dirty );
+					display_outline_proportional_rgb( new_xpos + LINESPACE + D_H_SPACE, ypos-(LINESPACE/2), color_idx_to_rgb(COL_YELLOW), color_idx_to_rgb(COL_BLACK), text, dirty );
 					display_ddd_box_clip_rgb( new_xpos, ypos-(LINESPACE/2), LINESPACE, LINESPACE, pc-2, pc+2 );
 					display_fillbox_wh_rgb( new_xpos+1, ypos-(LINESPACE/2)+1, LINESPACE-2, LINESPACE-2, pc, dirty );
 					break;
@@ -1872,7 +1880,7 @@ sint32 grund_t::weg_entfernen(waytype_t wegtyp, bool ribi_rem)
 		}
 
 		calc_image();
-		reliefkarte_t::get_karte()->calc_map_pixel(get_pos().get_2d());
+		minimap_t::get_instance()->calc_map_pixel(get_pos().get_2d());
 
 		return costs;
 	}
@@ -1939,7 +1947,7 @@ int grund_t::get_max_speed() const
 }
 
 
-bool grund_t::remove_everything_from_way(player_t* player_, waytype_t wt, ribi_t::ribi rem)
+bool grund_t::remove_everything_from_way(player_t* player, waytype_t wt, ribi_t::ribi rem)
 {
 	// check, if the way must be totally removed?
 	weg_t *weg = get_weg(wt);
@@ -1949,7 +1957,7 @@ bool grund_t::remove_everything_from_way(player_t* player_, waytype_t wt, ribi_t
 		const koord here = pos.get_2d();
 
 		// stops
-		if(flags&is_halt_flag  &&  (get_halt()->get_owner()==player_  || player_==welt->get_public_player())) {
+		if(flags&is_halt_flag  &&  (get_halt()->get_owner()==player  || player==welt->get_public_player())) {
 			bool remove_halt = get_typ()!=boden;
 			// remove only if there is no other way
 			if(get_weg_nr(1)==NULL) {
@@ -1970,7 +1978,7 @@ bool grund_t::remove_everything_from_way(player_t* player_, waytype_t wt, ribi_t
 #endif
 			}
 			if (remove_halt) {
-				if (!haltestelle_t::remove(player_, pos)) {
+				if (!haltestelle_t::remove(player, pos)) {
 					return false;
 				}
 			}
@@ -2038,7 +2046,7 @@ bool grund_t::remove_everything_from_way(player_t* player_, waytype_t wt, ribi_t
 					if((flags&has_way2)==0) {
 						if (add==ribi_t::none) {
 							// last way was belonging to this tunnel
-							tunnel->cleanup(player_);
+							tunnel->cleanup(player);
 							delete tunnel;
 						}
 					}
@@ -2066,7 +2074,7 @@ bool grund_t::remove_everything_from_way(player_t* player_, waytype_t wt, ribi_t
 				// make tunnel portals to normal ground
 				if (get_typ()==tunnelboden  &&  (flags&has_way1)==0) {
 					// remove remaining objs
-					obj_loesche_alle( player_ );
+					obj_loesche_alle( player );
 					// set to normal ground
 					welt->access(here)->kartenboden_setzen( new boden_t( pos, slope ) );
 					// now this is already deleted !
@@ -2081,7 +2089,7 @@ DBG_MESSAGE("tool_wayremover()","change remaining way to ribi %d",add);
 		}
 		// we have to pay?
 		if(costs) {
-			player_t::book_construction_costs(player_, costs, here, finance_wt);
+			player_t::book_construction_costs(player, costs, here, finance_wt);
 		}
 	}
 	return true;
