@@ -157,7 +157,7 @@ void gui_theme_t::init_gui_defaults()
 	gui_color_button_text_selected         = color_idx_to_rgb(COL_BLACK);
 
 	gui_color_colored_button_text          = color_idx_to_rgb(COL_BLACK);
-	gui_color_colored_button_text_selected = color_idx_to_rgb(COL_BLACK);
+	gui_color_colored_button_text_selected = color_idx_to_rgb(COL_WHITE);
 	gui_color_checkbox_text                = color_idx_to_rgb(COL_BLACK);
 	gui_color_checkbox_text_disabled       = color_idx_to_rgb(MN_GREY0);
 	gui_color_ticker_background            = color_idx_to_rgb(MN_GREY2);
