@@ -20,7 +20,7 @@
 #include "../obj/tunnel.h"
 #include "../obj/zeiger.h"
 
-#include "../gui/karte.h"
+#include "../gui/minimap.h"
 #include "../gui/tool_selector.h"
 
 #include "../simcity.h"
@@ -67,6 +67,9 @@ static special_obj_tpl<building_desc_t> const special_objects[] = {
 };
 
 
+sint16 hausbauer_t::largest_city_building_area = 1;
+
+
 /**
  * Compares house descriptors.
  * Order of comparison:
@@ -141,12 +144,30 @@ bool hausbauer_t::successfully_loaded()
 		// now insert the desc into the correct list.
 		switch(desc->get_type()) {
 			case building_desc_t::city_res:
+				if(  desc->get_x()*desc->get_y() > 9  ) {
+					dbg->fatal( "hausbauer_t::successfully_loaded()", "maximum city building size (3x3) but %s is (%sx%i)", desc->get_name(), desc->get_x(), desc->get_y() );
+				}
+				if(  desc->get_x()*desc->get_y() > largest_city_building_area  ) {
+					largest_city_building_area = desc->get_x()*desc->get_y();
+				}
 				city_residential.insert_ordered(desc,compare_building_desc);
 				break;
 			case building_desc_t::city_ind:
+				if(  desc->get_x()*desc->get_y() > 9  ) {
+					dbg->fatal( "hausbauer_t::successfully_loaded()", "maximum city building size (3x3) but %s is (%sx%i)", desc->get_name(), desc->get_x(), desc->get_y() );
+				}
+				if(  desc->get_x()*desc->get_y() > largest_city_building_area  ) {
+					largest_city_building_area = desc->get_x()*desc->get_y();
+				}
 				city_industry.insert_ordered(desc,compare_building_desc);
 				break;
 			case building_desc_t::city_com:
+				if(  desc->get_x()*desc->get_y() > 9  ) {
+					dbg->fatal( "hausbauer_t::successfully_loaded()", "maximum city building size (3x3) but %s is (%sx%i)", desc->get_name(), desc->get_x(), desc->get_y() );
+				}
+				if(  desc->get_x()*desc->get_y() > largest_city_building_area  ) {
+					largest_city_building_area = desc->get_x()*desc->get_y();
+				}
 				city_commercial.insert_ordered(desc,compare_building_desc);
 				break;
 
@@ -424,8 +445,10 @@ void hausbauer_t::remove( player_t *player, gebaeude_t *gb )
 							ground_recalc = false;
 						}
 						else if(  new_hgt <= welt->get_water_hgt(newk)  &&  new_slope == slope_t::flat  ) {
-							welt->access(newk)->kartenboden_setzen( new wasser_t( koord3d( newk, new_hgt ) ) );
+							wasser_t* sea = new wasser_t( koord3d( newk, new_hgt) );
+							welt->access(newk)->kartenboden_setzen( sea );
 							welt->calc_climate( newk, true );
+							sea->recalc_water_neighbours();
 						}
 						else {
 							if(  gr->get_grund_hang() == new_slope  ) {
@@ -444,6 +467,9 @@ void hausbauer_t::remove( player_t *player, gebaeude_t *gb )
 							}
 						}
 					}
+					else if (wasser_t* sea = dynamic_cast<wasser_t*>(gr)) {
+						sea->recalc_water_neighbours();
+					}
 				}
 			}
 		}
@@ -451,7 +477,7 @@ void hausbauer_t::remove( player_t *player, gebaeude_t *gb )
 }
 
 
-gebaeude_t* hausbauer_t::build(player_t* player_, koord3d pos, int org_layout, const building_desc_t* desc, void* param)
+gebaeude_t* hausbauer_t::build(player_t* player, koord3d pos, int org_layout, const building_desc_t* desc, void* param)
 {
 	gebaeude_t* first_building = NULL;
 	koord k;
@@ -476,7 +502,7 @@ gebaeude_t* hausbauer_t::build(player_t* player_, koord3d pos, int org_layout, c
 						DBG_MESSAGE("hausbauer_t::build()","get_tile() empty at %i,%i",k.x,k.y);
 				continue;
 			}
-			gebaeude_t *gb = new gebaeude_t(pos + k, player_, tile);
+			gebaeude_t *gb = new gebaeude_t(pos + k, player, tile);
 			if (first_building == NULL) {
 				first_building = gb;
 			}
@@ -515,7 +541,7 @@ gebaeude_t* hausbauer_t::build(player_t* player_, koord3d pos, int org_layout, c
 					}
 
 					// delete everything except vehicles
-					gr->obj_loesche_alle(player_);
+					gr->obj_loesche_alle(player);
 				}
 
 				// build new foundation
@@ -548,10 +574,14 @@ gebaeude_t* hausbauer_t::build(player_t* player_, koord3d pos, int org_layout, c
 				if(  desc->get_type() == building_desc_t::dock  ||  desc->get_type() == building_desc_t::flat_dock  ) {
 					// its a dock!
 					gb->set_yoff(0);
+
+					if (wasser_t* sea = dynamic_cast<wasser_t*>(gr)) {
+						sea->recalc_water_neighbours();
+					}
 				}
 			}
 			gr->calc_image();
-			reliefkarte_t::get_karte()->calc_map_pixel(gr->get_pos().get_2d());
+			minimap_t::get_instance()->calc_map_pixel(gr->get_pos().get_2d());
 		}
 	}
 	// remove only once ...
@@ -718,7 +748,7 @@ gebaeude_t *hausbauer_t::build_station_extension_depot(player_t *player, koord3d
 	}
 
 	// update minimap
-	reliefkarte_t::get_karte()->calc_map_pixel(gb->get_pos().get_2d());
+	minimap_t::get_instance()->calc_map_pixel(gb->get_pos().get_2d());
 
 	return gb;
 }
@@ -814,49 +844,54 @@ const building_desc_t* hausbauer_t::get_special(uint32 bev, building_desc_t::bty
  * @param level the minimum level of the house/station
  * @param cl allowed climates
  */
-static const building_desc_t* get_city_building_from_list(const vector_tpl<const building_desc_t*>& list, int level, uint16 time, climate cl, uint32 clusters )
+static const building_desc_t* get_city_building_from_list(const vector_tpl<const building_desc_t*>& list, int start_level, uint16 time, climate cl, uint32 clusters, koord minsize, koord maxsize )
 {
 	weighted_vector_tpl<const building_desc_t *> selections(16);
+	int level = start_level;
 
 //	DBG_MESSAGE("hausbauer_t::get_aus_liste()","target level %i", level );
 	const building_desc_t *desc_at_least=NULL;
 	FOR(vector_tpl<building_desc_t const*>, const desc, list) {
-		if(  desc->is_allowed_climate(cl)  &&  desc->get_distribution_weight()>0  &&  desc->is_available(time)  ) {
-				desc_at_least = desc;
-		}
-
 		const int thislevel = desc->get_level();
-		if(thislevel>level) {
+		if (thislevel > start_level + 6) {
+			break;
+		}
+		if( thislevel > level ) {
 			if (selections.empty()) {
 				// Nothing of the correct level. Continue with search on a higher level.
 				level = thislevel;
 			}
 			else {
-				// We already found something of the correct level; stop.
+				// We already found something of the correct level or the jump is too big; stop
 				break;
 			}
 		}
-
-		if(  thislevel == level  &&  desc->get_distribution_weight() > 0  ) {
-			if(  cl==MAX_CLIMATES  ||  desc->is_allowed_climate(cl)  ) {
-				if(  desc->is_available(time)  ) {
-//					DBG_MESSAGE("hausbauer_t::get_city_building_from_list()","appended %s at %i", desc->get_name(), thislevel );
-					/* Level, time period, and climate are all OK.
-					 * Now modify the chance rating by a factor based on the clusters.
-					 */
-					// FIXME: the factor should be configurable by the pakset/
-					int chance = desc->get_distribution_weight();
-					if(  clusters  ) {
-						uint32 my_clusters = desc->get_clusters();
-						if(  my_clusters & clusters  ) {
-							chance *= stadt_t::get_cluster_factor();
-						}
-						else {
-							chance /= stadt_t::get_cluster_factor();
-						}
+		if( (desc->is_allowed_climate(cl)   || cl==MAX_CLIMATES  )  &&
+		     desc->get_distribution_weight() > 0  &&
+		     desc->is_available(time)  &&
+		     // size check
+		  ( (desc->get_x() <= maxsize.x  &&  desc->get_y() <= maxsize.y  &&
+		     desc->get_x() >= minsize.x  &&  desc->get_y() >= minsize.y  ) ||
+		    (desc->get_x() <= maxsize.y  &&  desc->get_y() <= maxsize.x  &&
+		     desc->get_x() >= minsize.y  &&  desc->get_y() >= minsize.x  ) ) ) {
+			desc_at_least = desc;
+			if( thislevel == level ) {
+//				DBG_MESSAGE("hausbauer_t::get_city_building_from_list()","appended %s at %i", desc->get_name(), thislevel );
+				/* Level, time period, and climate are all OK.
+				 * Now modify the chance rating by a factor based on the clusters.
+				*/
+				// FIXME: the factor should be configurable by the pakset/
+				int chance = desc->get_distribution_weight();
+				if(  clusters  ) {
+					uint32 my_clusters = desc->get_clusters();
+					if(  my_clusters & clusters  ) {
+						chance *= stadt_t::get_cluster_factor();
+					}
+					else {
+						chance /= stadt_t::get_cluster_factor();
 					}
-					selections.append(desc, chance);
 				}
+				selections.append(desc, chance);
 			}
 		}
 	}
@@ -873,21 +908,21 @@ static const building_desc_t* get_city_building_from_list(const vector_tpl<const
 }
 
 
-const building_desc_t* hausbauer_t::get_commercial(int level, uint16 time, climate cl, uint32 clusters)
+const building_desc_t* hausbauer_t::get_commercial(int level, uint16 time, climate cl, uint32 clusters, koord minsize, koord maxsize )
 {
-	return get_city_building_from_list(city_commercial, level, time, cl, clusters);
+	return get_city_building_from_list(city_commercial, level, time, cl, clusters, minsize, maxsize );
 }
 
 
-const building_desc_t* hausbauer_t::get_industrial(int level, uint16 time, climate cl, uint32 clusters)
+const building_desc_t* hausbauer_t::get_industrial(int level, uint16 time, climate cl, uint32 clusters, koord minsize, koord maxsize )
 {
-	return get_city_building_from_list(city_industry, level, time, cl, clusters);
+	return get_city_building_from_list(city_industry, level, time, cl, clusters, minsize, maxsize );
 }
 
 
-const building_desc_t* hausbauer_t::get_residential(int level, uint16 time, climate cl, uint32 clusters)
+const building_desc_t* hausbauer_t::get_residential(int level, uint16 time, climate cl, uint32 clusters, koord minsize, koord maxsize )
 {
-	return get_city_building_from_list(city_residential, level, time, cl, clusters);
+	return get_city_building_from_list(city_residential, level, time, cl, clusters, minsize, maxsize );
 }
 
 
