@@ -9,8 +9,6 @@
 #define gui_label_info_h
 
 #include "gui_frame.h"
-#include "components/gui_label.h"
-#include "components/gui_textarea.h"
 #include "components/gui_textinput.h"
 #include "components/gui_location_view_t.h"
 #include "components/action_listener.h"
@@ -28,7 +26,6 @@ class label_info_t : public gui_frame_t, private action_listener_t
 private:
 	label_t *label;
 
-	gui_label_t player_name;
 	gui_textinput_t input;
 	location_view_t view;
 	char edit_name[256];
@@ -39,7 +36,7 @@ public:
 	bool action_triggered(gui_action_creator_t*, value_t) OVERRIDE;
 
 	// rotated map need new info ...
-	void map_rotate90( sint16 );
+	void map_rotate90( sint16 ) OVERRIDE;
 };
 
 #endif
