@@ -5,26 +5,27 @@
  */
 
 #include "../dataobj/schedule.h"
-#include "../dataobj/translator.h"
 #include "../dataobj/loadsave.h"
-#include "../gui/karte.h"
+#include "minimap.h"
 #include "../simline.h"
-#include "../gui/simwin.h"
+#include "simwin.h"
 #include "../simtool.h"
-#include "../simlinemgmt.h"
 #include "../utils/cbuffer_t.h"
 
 #include "line_management_gui.h"
 
 line_management_gui_t::line_management_gui_t(linehandle_t line, player_t* player_) :
-	schedule_gui_t(line->get_schedule()->copy(), player_, convoihandle_t() )
+	schedule_gui_t()
 {
-	this->line = line;
-	// has this line a single running convoi?
-	if(  line->count_convoys() > 0  ) {
-		reliefkarte_t::get_karte()->set_current_cnv( line->get_convoy(0) );
+	if (line.is_bound() ) {
+		schedule_gui_t::init(line->get_schedule()->copy(), player_, convoihandle_t() );
+
+		this->line = line;
+		// has this line a single running convoi?
+		if(  line->count_convoys() > 0  ) {
+			minimap_t::get_instance()->set_selected_cnv( line->get_convoy(0) );
+		}
 	}
-	show_line_selector(false);
 }
 
 
@@ -43,9 +44,9 @@ bool line_management_gui_t::infowin_event(const event_t *ev)
 			destroy_win( this );
 		}
 		else  {
-			if(  schedule_gui_t::infowin_event(ev)  ) {
-				return true;
-			}
+
+			bool swallowed = schedule_gui_t::infowin_event(ev);
+
 			if(  ev->ev_class == INFOWIN  &&  ev->ev_code == WIN_CLOSE  ) {
 				// update line schedule via tool!
 				tool_t *tool = create_tool( TOOL_CHANGE_LINE | SIMPLE_TOOL );
@@ -56,59 +57,60 @@ bool line_management_gui_t::infowin_event(const event_t *ev)
 				welt->set_tool( tool, line->get_owner() );
 				// since init always returns false, it is safe to delete immediately
 				delete tool;
+				return true;
 			}
+			return swallowed;
 		}
 	}
 	return false;
 }
 
 
-
-line_management_gui_t::line_management_gui_t() :
-	schedule_gui_t()
-{
-	show_line_selector(false);
-}
-
 void line_management_gui_t::rdwr(loadsave_t *file)
 {
-	// this handles only schedules of bound convois
-	// lines are handled by line_management_gui_t
-	uint8 player_nr;
 	scr_size size = get_windowsize();
-	if(  file->is_saving()  ) {
-		player_nr = line->get_owner()->get_player_nr();
+	size.rdwr( file );
+	simline_t::rdwr_linehandle_t(file, line);
+	// player that edits
+	uint8 player_nr;
+	if (file->is_saving()) {
+		player_nr = player->get_player_nr();
 	}
-	else {
+	file->rdwr_byte( player_nr );
+	player = welt->get_player(player_nr);
+
+	// save edited schedule
+	if(  file->is_loading()  ) {
 		// dummy types
 		old_schedule = new truck_schedule_t();
 		schedule = new truck_schedule_t();
 	}
-	size.rdwr( file );
-	file->rdwr_byte( player_nr );
-	simline_t::rdwr_linehandle_t(file, line);
-	old_schedule->rdwr(file);
 	schedule->rdwr(file);
-	if(  file->is_loading()  ) {
-		player_t *player = welt->get_player(player_nr);
-		assert(player);	// since it was alive during saving, this should never happen
+	old_schedule->rdwr(file);
 
+	if(  file->is_loading()  ) {
+		assert(player);	// since it was alive during saving, this should never happen
 		if(  line.is_bound()  &&  old_schedule->matches( welt, line->get_schedule() )  ) {
-			// now we can open the window ...
-			scr_coord const& pos = win_get_pos(this);
-			line_management_gui_t *w = new line_management_gui_t( line, player );
-			create_win(pos.x, pos.y, w, w_info, (ptrdiff_t)line.get_rep());
-			w->set_windowsize( size );
-			w->schedule->copy_from( schedule );
+
+			delete old_schedule;
+			old_schedule = NULL;
+
+			schedule_t *save_schedule = schedule->copy();
+
+			init(line->get_schedule()->copy(), line->get_owner(), convoihandle_t() );
+			// init replaced schedule, restore
+			schedule->copy_from(save_schedule);
+			delete save_schedule;
+
+			set_windowsize(size);
+
+			win_set_magic(this, (ptrdiff_t)line.get_rep());
 		}
 		else {
+			line = linehandle_t();
+			player = NULL; // prevent destructor from updating
+			destroy_win( this );
 			dbg->error( "line_management_gui_t::rdwr", "Could not restore schedule window for line id %i", line.get_id() );
 		}
-		player = NULL;
-		delete old_schedule;
-		delete schedule;
-		schedule = old_schedule = NULL;
-		line = linehandle_t();
-		destroy_win( this );
 	}
 }
