@@ -5,9 +5,6 @@
  */
 
 #include "schedule_gui.h"
-#include "components/gui_textinput.h"
-#include "components/action_listener.h"
-#include "gui_frame.h"
 
 #include "../linehandle_t.h"
 
@@ -17,15 +14,14 @@ class loadsave_t;
 class line_management_gui_t : public schedule_gui_t
 {
 public:
-	line_management_gui_t(linehandle_t line, player_t* player);
+	line_management_gui_t(linehandle_t line = linehandle_t(), player_t* player_ = NULL);
 	virtual ~line_management_gui_t();
 
 	bool infowin_event(event_t const*) OVERRIDE;
 
 	// stuff for UI saving
-	line_management_gui_t();
-	virtual void rdwr( loadsave_t *file );
-	virtual uint32 get_rdwr_id() { return magic_line_schedule_rdwr_dummy; }
+	void rdwr( loadsave_t *file ) OVERRIDE;
+	uint32 get_rdwr_id() OVERRIDE { return magic_line_schedule_rdwr_dummy; }
 
 
 private:
