@@ -8,7 +8,6 @@
 #include "../simdebug.h"
 
 #include <sys/stat.h>
-#include <time.h>
 
 #include "loadsave_frame.h"
 
@@ -113,8 +112,8 @@ loadsave_frame_t::loadsave_frame_t(bool do_load) : savegame_frame_t(".sve",false
 
 	if(do_load) {
 		set_name(translator::translate("Laden"));
-		easy_server.init( button_t::square_automatic, "Start this as a server", scr_coord(D_MARGIN_LEFT,0) );
-		add_component(&easy_server);
+		easy_server.init( button_t::square_automatic, "Start this as a server");
+		bottom_left_frame.add_component(&easy_server);
 	}
 	else {
 		set_filename(welt->get_settings().get_filename());
@@ -158,16 +157,6 @@ loadsave_frame_t::loadsave_frame_t(bool do_load) : savegame_frame_t(".sve",false
 }
 
 
-/**
- * need to shift the start server button to the lower left
- */
-void loadsave_frame_t::set_windowsize(scr_size size)
-{
-	savegame_frame_t::set_windowsize(size);
-	easy_server.align_to(&savebutton, ALIGN_CENTER_V, scr_coord( 0, 0 ) );
-}
-
-
 /**
  * Set the window associated helptext
  * @return the filename for the helptext, or NULL
