@@ -8,7 +8,7 @@
 #ifndef message_frame_h
 #define message_frame_h
 
-#include "../gui/simwin.h"
+#include "simwin.h"
 
 #include "gui_frame.h"
 #include "components/gui_button.h"
@@ -44,19 +44,13 @@ public:
 	 * @return the filename for the helptext, or NULL
 	 * @author Hj. Malthaner
 	 */
-	const char * get_help_filename() const {return "mailbox.txt";}
-
-	/**
-	* resize window in response to a resize event
-	* @author Hj. Malthaner
-	*/
-	void resize(const scr_coord delta);
+	const char * get_help_filename() const OVERRIDE {return "mailbox.txt";}
 
 	bool action_triggered(gui_action_creator_t*, value_t) OVERRIDE;
 
-	void rdwr(loadsave_t *);
+	void rdwr(loadsave_t *) OVERRIDE;
 
-	uint32 get_rdwr_id() { return magic_messageframe; }
+	uint32 get_rdwr_id() OVERRIDE { return magic_messageframe; }
 };
 
 #endif
