@@ -2,7 +2,7 @@
 #define message_option_h
 
 #include "../simmesg.h"
-#include "../gui/simwin.h"
+#include "simwin.h"
 
 #include "gui_frame.h"
 #include "components/action_listener.h"
@@ -30,11 +30,11 @@ public:
 	 * @return the filename for the helptext, or NULL
 	 * @author Hj. Malthaner
 	 */
-	const char * get_help_filename() const {return "mailbox.txt";}
+	const char * get_help_filename() const OVERRIDE {return "mailbox.txt";}
 
 	bool action_triggered(gui_action_creator_t*, value_t) OVERRIDE;
 
-	uint32 get_rdwr_id() { return magic_message_options; }
+	uint32 get_rdwr_id() OVERRIDE { return magic_message_options; }
 };
 
 #endif
