@@ -20,6 +20,7 @@
 #include "network_cmd_ingame.h"
 #include "network_cmp_pakset.h"
 #include "../simconst.h"
+#include "../simversion.h"
 
 #ifndef NETTOOL
 #include "../dataobj/environment.h"
@@ -165,7 +166,6 @@ SOCKET network_open_address(char const* cp, char const*& err)
 	}
 
 #else
-
 	// Address format e.g.: "example.com:13353", "128.0.0.1:13353" or "[::1]:80"
 	// this should be replaced with a URI parser...
 	static char err_str[256];
@@ -206,6 +206,7 @@ SOCKET network_open_address(char const* cp, char const*& err)
 #else
 	vector_tpl<std::string> const& ips = env_t::listen;
 #endif
+
 	// For each address in the list of listen addresses try and create a socket to transmit on
 	// Use the first one which works
 	for (uint i = 0; !connected && i != ips.get_count(); ++i) {
@@ -224,7 +225,11 @@ SOCKET network_open_address(char const* cp, char const*& err)
 		// Fill out remote address structure
 		if (  (ret = getaddrinfo(cpaddress.c_str(), cpport.c_str(), &remote_hints, &remote)) != 0) {
 			sprintf( err_str, "Bad address %s", cp );
-			RET_ERR_STR;
+			if(  i+1==ips.get_count()  ) {
+				RET_ERR_STR;
+			}
+			// maybe it is an IPv4 only on the second interface ..
+			continue;
 		}
 
 		// Set up local addrinfo
@@ -816,11 +821,45 @@ void network_core_shutdown()
 #include "../utils/cbuffer_t.h"
 #include "network_file_transfer.h"
 
-bool get_external_IP( cbuffer_t &myIPaddr )
+bool get_external_IP( cbuffer_t &myIPaddr, cbuffer_t &altIPaddr )
 {
 	myIPaddr.clear();
-	// query "simutrans-forum.de/get_IP.php" for IP (faster than asking router)
-	const char *err = network_http_get( "simutrans-forum.de:80", "/get_IP.php", myIPaddr );
+	altIPaddr.clear();
+	// query "simutrans-forum.de/get_IP.php" for IP (faster than asking router and we can get IP6 too)
+	const char *err = network_http_get( QUERY_ADDR_IP, QUERY_ADDR_URL, altIPaddr );
+	// if we have a dual stack system, IP6 should be preferred, i.e. we have now the IP6
+	if(  err==NULL  &&  strstr(altIPaddr,":")  ) {
+		// try to get and IPv4 address too
+		if(  !network_http_get( QUERY_ADDR_IPv4_ONLY, QUERY_ADDR_URL, myIPaddr )  ) {
+			if(  strcmp( myIPaddr, altIPaddr ) == 0   ) {
+				// same, no alternative address
+				altIPaddr.clear();
+			}
+		}
+	}
+	else {
+		myIPaddr = altIPaddr;
+		altIPaddr.clear();
+	}
+
+#if 0
+	// enable to try to get a symbolic name for IPv4
+	if(  !err  ) {
+		struct sockaddr_in sin;
+		memset(&sin, 0, sizeof(sin));
+		sin.sin_family      = AF_INET;
+		sin.sin_addr.s_addr = inet_addr(myIPaddr);
+		sin.sin_port        = 0; // If 0, port is chosen by system
+		char hostname[1024];
+		hostname[0] = 0;
+
+		int failed = getnameinfo((const sockaddr *)&sin, sizeof(sin), hostname, lengthof(hostname), NULL, 0, 0);
+		if(  !failed  &&  *hostname  ) {
+			myIPaddr.clear();
+			myIPaddr.append( hostname );
+		}
+	}
+#endif
 	return err==NULL;
 }
 
@@ -844,7 +883,8 @@ extern "C" {
 #define UPNP_LOCAL_PORT_ANY 0
 #endif
 
-bool prepare_for_server( char *externalIPAddress, int port )
+
+bool prepare_for_server( char *externalIPAddress, char *externalAltIPAddress, int port )
 {
 	char lanaddr[64] = "unset";	/* my ip address on the LAN */
 	int error = 0;
@@ -861,15 +901,14 @@ bool prepare_for_server( char *externalIPAddress, int port )
 		struct IGDdatas data;
 
 		UPNP_GetValidIGD( devlist, &urls, &data, lanaddr, sizeof(lanaddr) );
-		// this could query the connection status
-//		if(  UPNP_GetStatusInfo( urls->controlURL, data->first.servicetype, status, &uptime, lastconnerr) == UPNPCOMMAND_SUCCESS  ) {
-//		}
-		// but we must know our IP address first
+		// we must know our IP address first
 		if(  UPNP_GetExternalIPAddress(urls.controlURL, data.first.servicetype, externalIPAddress) ==  UPNPCOMMAND_SUCCESS  ) {
 			// this is our ID (at least the routes tells us this)
 			char eport[19];
 			char *iport = eport;
 			sprintf( eport, "%d", port );
+			// remove anz forwarding
+			UPNP_DeletePortMapping(urls.controlURL, data.first.servicetype, eport, "TCP", NULL);
 			// setting up tcp redirect forever (last parameter "0")
 			if(  UPNP_AddPortMapping(urls.controlURL, data.first.servicetype, eport, iport, lanaddr, "simutrans", "TCP", 0, "0")  ==  UPNPCOMMAND_SUCCESS  ) {
 				// ok, we have our ID and redirected a port to us
@@ -884,15 +923,52 @@ bool prepare_for_server( char *externalIPAddress, int port )
 	}
 	freeUPNPDevlist(devlist);
 
-	if(  !has_IP  ) {
-		cbuffer_t myIPaddr;
-		// lets get IP by query "simutrans-forum.de/get_IP.php" for IP and assume that the redirection is working
-		const char *err = network_http_get( "simutrans-forum.de:80", "/get_IP.php", myIPaddr );
-		if(  !err  ) {
-			has_IP = true;
-			strcpy( externalIPAddress, myIPaddr.get_str() );
+	externalAltIPAddress[0] = 0;
+#if 1
+	// use the same routine as later the announce routine, otherwise update with dynamic IP fails
+	cbuffer_t myIPaddr, altIPaddr;
+	if(  get_external_IP( myIPaddr, altIPaddr )  ) {
+		has_IP = true;
+		strcpy( externalIPAddress, myIPaddr );
+		if(  altIPaddr.len()  ) {
+			strcpy( externalAltIPAddress, altIPaddr );
 		}
 	}
+#else
+	// now we have (or have not) the IPv4 at this point (due to the protocol), we check for IP6 too or try to get at least an IP addr
+	cbuffer_t myIPaddr;
+	// lets get IP by query "simutrans-forum.de/get_IP.php" for IP and assume that the redirection is working
+	const char *err = network_http_get( "simutrans-forum.de:80", "/get_IP.php", myIPaddr );
+	if(  !err  ) {
+		if(  has_IP  ) {
+			if(  strcmp(externalIPAddress, myIPaddr.get_str())!=0  ) {
+				strcpy( externalAltIPAddress, myIPaddr.get_str() );
+			}
+		}
+		else {
+			strcpy( externalIPAddress, myIPaddr.get_str() );
+			has_IP = true;
+		}
+	}
+
+	// we have an external IP, let's find if we have a DNS name for it
+	if (!network_initialize()) {
+		return has_IP;
+	}
+
+	struct sockaddr_in sin;
+	memset(&sin, 0, sizeof(sin));
+	sin.sin_family      = AF_INET;
+	sin.sin_addr.s_addr = inet_addr(externalIPAddress);
+	sin.sin_port        = 0; // If 0, port is chosen by system
+	char hostname[1024];
+	hostname[0] = 0;
+
+	int failed = getnameinfo((const sockaddr *)&sin, sizeof(sin), hostname, lengthof(hostname), NULL, 0, 0);
+	if(  !failed  &&  *hostname  ) {
+		strcpy( externalIPAddress, hostname );
+	}
+#endif
 	return has_IP;
 }
 
@@ -924,7 +1000,6 @@ void remove_port_forwarding( int port )
 			// this is our ID (at least the routes tells us this)
 			char eport[19];
 			sprintf( eport, "%d", port );
-			// setting up tcp redirect forever (last parameter "0")
 			UPNP_DeletePortMapping(urls.controlURL, data.first.servicetype, eport, "TCP", NULL);
 		}
 		FreeUPNPUrls(&urls);
@@ -932,9 +1007,9 @@ void remove_port_forwarding( int port )
 	freeUPNPDevlist(devlist);
 }
 #else
-// or we jsut get only our IP and hope we are not behind a router ...
+// or we just get only our IP and hope we are not behind a router ...
 
-bool prepare_for_server( char *externalIPAddress, int )
+bool prepare_for_server(char *externalIPAddress, char *, int)
 {
 	cbuffer_t myIPaddr;
 	// lets get IP by query "simutrans-forum.de/get_IP.php" for IP and assume that the redirection is working
