@@ -17,7 +17,7 @@
 
 #include "../simworld.h"
 #include "../simmenu.h"
-#include "../gui/simwin.h"
+#include "simwin.h"
 #include "optionen.h"
 #include "display_settings.h"
 #include "sprachen.h"
@@ -30,22 +30,26 @@
 
 enum BUTTONS {
 	BUTTON_LANGUAGE = 0,
-	BUTTON_PLAYERS,
-	BUTTON_PLAYER_COLORS,
-	BUTTON_DISPLAY,
-	BUTTON_SOUND,
 	BUTTON_NEW_GAME,
+	BUTTON_PLAYERS,
 	BUTTON_LOAD_GAME,
+	BUTTON_PLAYER_COLORS,
 	BUTTON_SAVE_GAME,
+	BUTTON_DISPLAY,
 	BUTTON_LOAD_SCENARIO,
+	BUTTON_SOUND,
 	BUTTON_SCENARIO_INFO,
 	BUTTON_QUIT
 };
 
 static char const *const option_buttons_text[] =
 {
-	"Sprache", "Spieler(mz)", "Farbe", "Helligk.", "Sound",
-	"Neue Karte", "Load game", "Speichern", "Load scenario", "Scenario", "Beenden"
+	"Sprache", "Neue Karte",
+	"Spieler(mz)", "Load game",
+	"Farbe", "Speichern",
+	"Helligk.", "Load scenario",
+	"Sound", "Scenario",
+	"Beenden"
 };
 
 
@@ -55,43 +59,30 @@ optionen_gui_t::optionen_gui_t() :
 	assert(  lengthof(option_buttons)==lengthof(option_buttons_text)  );
 	assert(  lengthof(option_buttons)==BUTTON_QUIT+1  );
 
-	scr_coord cursor = scr_coord( D_MARGIN_LEFT, D_MARGIN_TOP );
-
+	set_table_layout(2,0);
+	set_force_equal_columns(true);
 
 	for(  uint i=0;  i<lengthof(option_buttons);  i++  ) {
 
-		switch(i) {
-
-			// Enable/disable scenario button
-			case BUTTON_SCENARIO_INFO:
-				if(  !welt->get_scenario()->active()  ) {
-					option_buttons[BUTTON_SCENARIO_INFO].disable();
-				}
-				break;
-
-			// Move cursor to the second column
-			case BUTTON_NEW_GAME:
-				cursor = scr_coord ( cursor.x+D_BUTTON_WIDTH+D_H_SPACE,D_MARGIN_TOP);
-				break;
-
-			// Squeeze in divider
-			case BUTTON_QUIT:
-				cursor.y -= D_V_SPACE;
-				divider.init( scr_coord(D_MARGIN_LEFT, cursor.y), cursor.x - D_MARGIN_LEFT + D_BUTTON_WIDTH );
-				add_component( &divider );
-				cursor.y += divider.get_size().h; //+D_V_SPACE;
-				break;
-
-		}
-
-		// Add button at cursor
-		option_buttons[i].init( button_t::roundbox, option_buttons_text[i], cursor);
+		add_component(option_buttons + i);
+		option_buttons[i].init(button_t::roundbox | button_t::flexible, option_buttons_text[i]);
 		option_buttons[i].add_listener(this);
-		add_component( option_buttons+i );
-		cursor.y += D_BUTTON_HEIGHT + D_V_SPACE;
+
+		if (i == BUTTON_SCENARIO_INFO) {
+			// Enable/disable scenario button
+			if(  !welt->get_scenario()->active()  ) {
+				option_buttons[BUTTON_SCENARIO_INFO].disable();
+			}
+			// Squeeze in divider
+			new_component_span<gui_divider_t>(2);
+			// empty cell left of quit button
+			new_component<gui_empty_t>();
+		}
 	}
 
-	set_windowsize( scr_size( D_BUTTON_WIDTH + D_MARGIN_RIGHT, D_TITLEBAR_HEIGHT + D_MARGIN_BOTTOM - D_V_SPACE ) + cursor );
+	reset_min_windowsize();
+	set_windowsize(get_min_windowsize());
+	set_resizemode(gui_frame_t::horizontal_resize);
 }
 
 
