@@ -19,7 +19,7 @@ void goods_reader_t::register_obj(obj_desc_t *&data)
 
 	checksum_t *chk = new checksum_t();
 	desc->calc_checksum(chk);
-	pakset_info_t::append(desc->get_name(), chk);
+	pakset_info_t::append(desc->get_name(), get_type(), chk);
 }
 
 
