@@ -767,7 +767,10 @@ bool scenario_t::open_info_win(const char* tab) const
 	scenario_info_t *si = (scenario_info_t*)win_get_magic(magic_scenario_info);
 	if (si == NULL) {
 		si = new scenario_info_t();
-		create_win(si, w_info, magic_scenario_info);
+		if (create_win(si, w_info, magic_scenario_info) < 0) {
+			// failed
+			return false;
+		}
 	}
 	si->open_tab(tab);
 	return true; // dummy return value
@@ -777,7 +780,7 @@ bool scenario_t::open_info_win(const char* tab) const
 void scenario_t::rdwr(loadsave_t *file)
 {
 	file->rdwr_short(what_scenario);
-	if (file->get_version() <= 111004) {
+	if (file->is_version_less(111, 5)) {
 		uint32 city_nr = 0;
 		file->rdwr_long(city_nr);
 		sint64 factor = 0;
@@ -872,7 +875,7 @@ void scenario_t::rdwr(loadsave_t *file)
 	}
 
 	// cached strings
-	if (file->get_version() >= 120003) {
+	if (file->is_version_atleast(120, 3)) {
 		dynamic_string::rdwr_cache(file);
 	}
 
