@@ -12,7 +12,7 @@
 #include "scenario_info.h"
 #include "messagebox.h"
 
-#include "../gui/simwin.h"
+#include "simwin.h"
 #include "../simworld.h"
 #include "../simmenu.h"
 
@@ -41,22 +41,14 @@ scenario_frame_t::scenario_frame_t() : savegame_frame_t(NULL, true, NULL, false)
 	}
 	this->add_path(pakset_scenario);
 
-	easy_server.init( button_t::square_automatic, "Start this as a server", scr_coord(D_MARGIN_LEFT,0) );
-	add_component(&easy_server);
+	easy_server.init( button_t::square_automatic, "Start this as a server");
+	bottom_left_frame.add_component(&easy_server);
 
 	set_name(translator::translate("Load scenario"));
 	set_focus(NULL);
 }
 
 
-void scenario_frame_t::set_windowsize(scr_size size)
-{
-	savegame_frame_t::set_windowsize(size);
-	easy_server.align_to(&savebutton, ALIGN_CENTER_V, scr_coord( 0, 0 ) );
-}
-
-
-
 /**
  * Action, started after button pressing.
  * @author Hansjrg Malthaner
@@ -94,7 +86,7 @@ bool scenario_frame_t::item_action(const char *fullpath)
 
 const char *scenario_frame_t::get_info(const char *filename)
 {
-	static char info[1024];
+	static char info[PATH_MAX];
 
 	sprintf(info,"%s",this->get_filename(filename, false).c_str());
 
@@ -104,7 +96,7 @@ const char *scenario_frame_t::get_info(const char *filename)
 
 bool scenario_frame_t::check_file( const char *filename, const char * )
 {
-	char buf[1024];
+	char buf[PATH_MAX];
 	sprintf( buf, "%s/scenario.nut", filename );
 	if (FILE* const f = dr_fopen(buf, "r")) {
 		fclose(f);
