@@ -24,21 +24,19 @@ protected:
 	 * Action that's started by the press of a button.
 	 * @author Hansjrg Malthaner
 	 */
-	virtual bool item_action(const char *fullpath);
+	bool item_action(const char *fullpath) OVERRIDE;
 
 	/**
 	 * Action, started after X-Button pressing
 	 * @author V. Meyer
 	 */
-	virtual bool del_action(const char *f) { return item_action(f); }
+	bool del_action(const char *f) OVERRIDE { return item_action(f); }
 
 	// returns extra file info
-	virtual const char *get_info(const char *fname);
+	const char *get_info(const char *fname) OVERRIDE;
 
 	// true, if valid
-	virtual bool check_file( const char *filename, const char *suffix );
-
-	virtual void set_windowsize(scr_size size);
+	bool check_file( const char *filename, const char *suffix ) OVERRIDE;
 
 public:
 	/**
@@ -46,7 +44,7 @@ public:
 	* @return the filename for the helptext, or NULL
 	* @author Hj. Malthaner
 	*/
-	virtual const char * get_help_filename() const { return "scenario.txt"; }
+	const char * get_help_filename() const OVERRIDE { return "scenario.txt"; }
 
 	scenario_frame_t();
 };
