@@ -18,11 +18,18 @@ private:
 
 private:
 	const pedestrian_desc_t *desc;
+	uint16 animation_steps;
+
+	uint16 steps_offset;
+	uint16 ped_offset;
+	bool on_left;
+
+	bool list_empty();
 
 protected:
-	void rdwr(loadsave_t *file);
+	void rdwr(loadsave_t *file) OVERRIDE;
 
-	void calc_image();
+	void calc_image() OVERRIDE;
 
 	/**
 	 * Creates pedestrian at position given by @p gr.
@@ -37,19 +44,35 @@ public:
 
 	const pedestrian_desc_t *get_desc() const { return desc; }
 
-	const char *get_name() const {return "Fussgaenger";}
-	typ get_typ() const { return pedestrian; }
+	const char *get_name() const OVERRIDE {return "Fussgaenger";}
+	typ get_typ() const OVERRIDE { return pedestrian; }
 
-	sync_result sync_step(uint32 delta_t);
+	void info(cbuffer_t & buf) const OVERRIDE;
 
-	virtual grund_t* hop_check();
-	virtual void hop(grund_t* gr);
+	sync_result sync_step(uint32 delta_t) OVERRIDE;
+
+	///@ returns true if pedestrian walks on the left side of the road
+	bool is_on_left() const { return on_left; }
+
+	void calc_disp_lane();
+
+	void rotate90() OVERRIDE;
+
+	// overloaded to enable animations
+	image_id get_image() const OVERRIDE;
+
+	void get_screen_offset( int &xoff, int &yoff, const sint16 raster_width ) const OVERRIDE;
+
+	grund_t* hop_check() OVERRIDE;
+	void hop(grund_t* gr) OVERRIDE;
 
 	// class register functions
 	static bool register_desc(const pedestrian_desc_t *desc);
 	static bool successfully_loaded();
 
 	static void generate_pedestrians_at(koord3d k, int &count);
+
+	static void build_timeline_list( karte_t *welt );
 };
 
 #endif
