@@ -401,7 +401,7 @@ void player_t::calc_assets()
 		if(  cnv->get_owner() == this  ) {
 			sint64 restwert = cnv->calc_restwert();
 			assets[TT_ALL] += restwert;
-			assets[finance->translate_waytype_to_tt(cnv->front()->get_waytype())] += restwert;
+			assets[finance->translate_waytype_to_tt(cnv->front()->get_desc()->get_waytype())] += restwert;
 		}
 	}
 
@@ -411,7 +411,7 @@ void player_t::calc_assets()
 			FOR(slist_tpl<vehicle_t*>, const veh, depot->get_vehicle_list()) {
 				sint64 restwert = veh->calc_sale_value();
 				assets[TT_ALL] += restwert;
-				assets[finance->translate_waytype_to_tt(veh->get_waytype())] += restwert;
+				assets[finance->translate_waytype_to_tt(veh->get_desc()->get_waytype())] += restwert;
 			}
 		}
 	}
@@ -639,7 +639,7 @@ void player_t::rdwr(loadsave_t *file)
 {
 	xml_tag_t sss( file, "spieler_t" );
 
-	if(file->get_version() < 112005) {
+	if(file->is_version_less(112, 5)) {
 		sint64 konto = finance->get_account_balance();
 		file->rdwr_longlong(konto);
 		finance->set_account_balance(konto);
@@ -649,13 +649,13 @@ void player_t::rdwr(loadsave_t *file)
 		finance->set_account_overdrawn( account_overdrawn );
 	}
 
-	if(file->get_version()<101000) {
+	if(file->is_version_less(101, 0)) {
 		// ignore steps
 		sint32 ldummy=0;
 		file->rdwr_long(ldummy);
 	}
 
-	if(file->get_version()<99009) {
+	if(file->is_version_less(99, 9)) {
 		sint32 farbe;
 		file->rdwr_long(farbe);
 		player_color_1 = (uint8)farbe*2;
@@ -667,10 +667,10 @@ void player_t::rdwr(loadsave_t *file)
 	}
 
 	sint32 halt_count=0;
-	if(file->get_version()<99008) {
+	if(file->is_version_less(99, 8)) {
 		file->rdwr_long(halt_count);
 	}
-	if(file->get_version()<=112002) {
+	if(file->is_version_less(112, 3)) {
 		sint32 haltcount = 0;
 		file->rdwr_long(haltcount);
 	}
@@ -681,14 +681,14 @@ void player_t::rdwr(loadsave_t *file)
 	file->rdwr_bool(active);
 
 	// state is not saved anymore
-	if(file->get_version()<99014) {
+	if(file->is_version_less(99, 14)) {
 		sint32 ldummy=0;
 		file->rdwr_long(ldummy);
 		file->rdwr_long(ldummy);
 	}
 
 	// the AI stuff is now saved directly by the different AI
-	if(  file->get_version()<101000) {
+	if(  file->is_version_less(101, 0)) {
 		sint32 ldummy = -1;
 		file->rdwr_long(ldummy);
 		file->rdwr_long(ldummy);
@@ -711,7 +711,7 @@ DBG_DEBUG("player_t::rdwr()","player %i: loading %i halts.",welt->sp2num( this )
 	}
 
 	// headquarters stuff
-	if (file->get_version() < 86004)
+	if (file->is_version_less(86, 4))
 	{
 		headquarter_level = 0;
 		headquarter_pos = koord::invalid;
@@ -728,11 +728,11 @@ DBG_DEBUG("player_t::rdwr()","player %i: loading %i halts.",welt->sp2num( this )
 	}
 
 	// line management
-	if(file->get_version()>=88003) {
+	if(file->is_version_atleast(88, 3)) {
 		simlinemgmt.rdwr(file,this);
 	}
 
-	if(file->get_version()>102002) {
+	if(file->is_version_atleast(102, 3)) {
 		// password hash
 		for(  int i=0;  i<20;  i++  ) {
 			file->rdwr_byte(pwd_hash[i]);
@@ -744,12 +744,12 @@ DBG_DEBUG("player_t::rdwr()","player %i: loading %i halts.",welt->sp2num( this )
 	}
 
 	// save the name too
-	if(  file->get_version() > 102003  ) {
+	if(  file->is_version_atleast(102, 4)  ) {
 		file->rdwr_str( player_name_buf, lengthof(player_name_buf) );
 	}
 
 	// save age
-	if(  file->get_version() >= 112002  ) {
+	if(  file->is_version_atleast(112, 2)  ) {
 		file->rdwr_short( player_age );
 	}
 }
