@@ -39,7 +39,7 @@ protected:
 	sint32 time_to_life;
 
 protected:
-	virtual waytype_t get_waytype() const { return road_wt; }
+	waytype_t get_waytype() const OVERRIDE { return road_wt; }
 
 	road_user_t();
 
@@ -53,22 +53,22 @@ protected:
 public:
 	virtual ~road_user_t();
 
-	const char *get_name() const = 0;
-	typ get_typ() const  = 0;
+	const char *get_name() const OVERRIDE = 0;
+	typ get_typ() const OVERRIDE  = 0;
 
 	/**
 	 * Open a new observation window for the object.
 	 * @author Hj. Malthaner
 	 */
-	virtual void show_info();
+	void show_info() OVERRIDE;
 
-	void rdwr(loadsave_t *file);
+	void rdwr(loadsave_t *file) OVERRIDE;
 
 	// finalizes direction
-	void finish_rd();
+	void finish_rd() OVERRIDE;
 
 	// we allow to remove all cars etc.
-	const char *is_deletable(const player_t *) { return NULL; }
+	const char *is_deletable(const player_t *) OVERRIDE { return NULL; }
 };
 
 
@@ -93,14 +93,14 @@ private:
 
 	uint32 ms_traffic_jam;
 
-	grund_t* hop_check();
+	grund_t* hop_check() OVERRIDE;
 
 	void calc_disp_lane();
 
 protected:
-	void rdwr(loadsave_t *file);
+	void rdwr(loadsave_t *file) OVERRIDE;
 
-	void calc_image();
+	void calc_image() OVERRIDE;
 
 public:
 	private_car_t(loadsave_t *file);
@@ -113,22 +113,22 @@ public:
 
 	virtual ~private_car_t();
 
-	virtual void rotate90();
+	void rotate90() OVERRIDE;
 
 	const citycar_desc_t *get_desc() const { return desc; }
 
-	sync_result sync_step(uint32 delta_t);
+	sync_result sync_step(uint32 delta_t) OVERRIDE;
 
-	void hop(grund_t *gr);
+	void hop(grund_t *gr) OVERRIDE;
 	bool ist_weg_frei(grund_t *gr);
 
-	void enter_tile(grund_t* gr);
+	void enter_tile(grund_t* gr) OVERRIDE;
 
 	void calc_current_speed(grund_t*);
 	uint16 get_current_speed() const {return current_speed;}
 
-	const char *get_name() const {return "Verkehrsteilnehmer";}
-	typ get_typ() const { return road_user; }
+	const char *get_name() const OVERRIDE {return "Verkehrsteilnehmer";}
+	typ get_typ() const OVERRIDE { return road_user; }
 
 	/**
 	 * @return a description string for the object
@@ -136,10 +136,10 @@ public:
 	 * @author Hj. Malthaner
 	 * @see simwin
 	 */
-	virtual void info(cbuffer_t & buf) const;
+	void info(cbuffer_t & buf) const OVERRIDE;
 
 	// true, if this vehicle did not moved for some time
-	virtual bool is_stuck() { return current_speed==0;}
+	bool is_stuck() OVERRIDE { return current_speed==0;}
 
 	/* this function builds the list of the allowed citycars
 	 * it should be called every month and in the beginning of a new game
@@ -152,12 +152,12 @@ public:
 	static bool successfully_loaded();
 
 	// since we must consider overtaking, we use this for offset calculation
-	virtual void get_screen_offset( int &xoff, int &yoff, const sint16 raster_width ) const;
+	void get_screen_offset( int &xoff, int &yoff, const sint16 raster_width ) const OVERRIDE;
 
-	virtual overtaker_t *get_overtaker() { return this; }
+	overtaker_t *get_overtaker() OVERRIDE { return this; }
 
 	// Overtaking for city cars
-	virtual bool can_overtake(overtaker_t *other_overtaker, sint32 other_speed, sint16 steps_other);
+	bool can_overtake(overtaker_t *other_overtaker, sint32 other_speed, sint16 steps_other) OVERRIDE;
 };
 
 #endif
