@@ -32,8 +32,6 @@
 #	else
 #		include <sys\unistd.h>
 #	endif
-#   undef PATH_MAX
-#	define PATH_MAX MAX_PATH
 #	include "simdebug.h"
 #else
 #	include <limits.h>
@@ -406,12 +404,12 @@ const char *dr_query_fontpath(int which)
 		"/boot/system/non-packaged/data/fonts/",
 		"/boot/home/config/non-packaged/data/fonts/",
 		"~/config/non-packaged/data/fonts/",
-		"/boot/system/data/fonts/ttfonts/"
+		"/boot/system/data/fonts/ttfonts/",
 #else
 		"~/.fonts/",
 		"~/.local/share/fonts/",
 		"/usr/share/fonts/truetype/",
-		"/usr/X11R6/lib/X11/fonts/ttfonts/"
+		"/usr/X11R6/lib/X11/fonts/ttfonts/",
 		"/usr/local/sharefonts/truetype/",
 		"/usr/share/fonts/",
 		"/usr/X11R6/lib/X11/fonts/",
@@ -1026,6 +1024,28 @@ int sysmain(int const argc, char** const argv)
 	if (length != -1) {
 		buffer[length] = '\0'; /* readlink() does not NUL-terminate */
 		argv[0] = buffer;
+	} else if (strchr(argv[0], '/') == NULL) {
+		// no /proc, no '/' in argv[0] => search PATH
+		const char* path = getenv("PATH");
+		if (path != NULL) {
+			size_t flen = strlen(argv[0]);
+			for (;;) { /* for each directory in PATH */
+				size_t dlen = strcspn(path, ":");
+				if (dlen > 0 && dlen + flen + 2 < lengthof(buffer)) {
+					// buffer = dir '/' argv[0] '\0'
+					memcpy(buffer, path, dlen);
+					buffer[dlen] = '/';
+					memcpy(buffer + dlen + 1, argv[0], flen + 1);
+					if (access(buffer, X_OK) == 0) {
+						argv[0] = buffer;
+						break; /* found it! */
+					}
+				}
+				if (path[dlen] == '\0')
+					break;
+				path += dlen + 1; /* skip ':' */
+			}
+		}
 	}
 #	endif
 	// no process file system => need to parse argv[0]
