@@ -94,7 +94,7 @@ public:
 	/**
 	 * @return true if this tool operates over the grid, not the map tiles.
 	 */
-	bool is_grid_tool() const {return true;}
+	bool is_grid_tool() const OVERRIDE {return true;}
 
 	bool update_pos_after_use() const OVERRIDE { return true; }
 };
@@ -230,9 +230,9 @@ private:
 class tool_plant_tree_t : public kartenboden_tool_t {
 public:
 	tool_plant_tree_t() : kartenboden_tool_t(TOOL_PLANT_TREE | GENERAL_TOOL) {}
-	image_id get_icon(player_t *) const { return baum_t::get_count() > 0 ? icon : IMG_EMPTY; }
+	image_id get_icon(player_t *) const OVERRIDE { return baum_t::get_count() > 0 ? icon : IMG_EMPTY; }
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate( "Plant tree" ); }
-	bool init(player_t*) { return baum_t::get_count() > 0; }
+	bool init(player_t*) OVERRIDE { return baum_t::get_count() > 0; }
 	char const* move(player_t* const player, uint16 const b, koord3d const k) OVERRIDE;
 	bool move_has_effects() const OVERRIDE { return true; }
 	char const* work(player_t*, koord3d) OVERRIDE;
@@ -271,7 +271,7 @@ protected:
 
 	virtual way_desc_t const* get_desc(uint16, bool) const;
 	void calc_route( way_builder_t &bauigel, const koord3d &, const koord3d & );
-	virtual void start_at( koord3d &new_start );
+	void start_at( koord3d &new_start ) OVERRIDE;
 
 public:
 	tool_build_way_t(uint16 const id = TOOL_BUILD_WAY | GENERAL_TOOL) : two_click_tool_t(id), desc() {}
@@ -551,8 +551,8 @@ public:
 	char const* get_tooltip(player_t const*) const OVERRIDE { return env_t::networkmode ? translator::translate("deactivated in online mode") : translator::translate("Lock game"); }
 	image_id get_icon(player_t*) const OVERRIDE { return env_t::networkmode ? IMG_EMPTY : icon; }
 	// deactivate in network mode
-	bool init(player_t *) { return !env_t::networkmode; }
-	const char *work( player_t *, koord3d );
+	bool init(player_t *) OVERRIDE { return !env_t::networkmode; }
+	const char *work( player_t *, koord3d ) OVERRIDE;
 	bool is_init_network_save() const OVERRIDE { return true; }
 };
 
@@ -569,9 +569,9 @@ public:
 class tool_forest_t : public two_click_tool_t {
 public:
 	tool_forest_t() : two_click_tool_t(TOOL_FOREST | GENERAL_TOOL) {}
-	image_id get_icon(player_t *) const { return baum_t::get_count() > 0 ? icon : IMG_EMPTY; }
+	image_id get_icon(player_t *) const  OVERRIDE { return baum_t::get_count() > 0 ? icon : IMG_EMPTY; }
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("Add forest"); }
-	bool init( player_t *player) { return  baum_t::get_count() > 0  &&  two_click_tool_t::init(player); }
+	bool init( player_t *player) OVERRIDE { return  baum_t::get_count() > 0  &&  two_click_tool_t::init(player); }
 private:
 	char const* do_work(player_t*, koord3d const&, koord3d const&) OVERRIDE;
 	void mark_tiles(player_t*, koord3d const&, koord3d const&) OVERRIDE;
@@ -603,8 +603,8 @@ private:
 class tool_make_stop_public_t : public tool_t {
 public:
 	tool_make_stop_public_t() : tool_t(TOOL_MAKE_STOP_PUBLIC | GENERAL_TOOL) {}
-	bool init(player_t * );
-	bool exit(player_t *s ) { return init(s); }
+	bool init(player_t * ) OVERRIDE;
+	bool exit(player_t *s ) OVERRIDE { return init(s); }
 	char const* get_tooltip(player_t const*) const OVERRIDE;
 	char const* move(player_t*, uint16 /* buttonstate */, koord3d) OVERRIDE;
 	bool move_has_effects() const OVERRIDE { return true; }
@@ -613,6 +613,23 @@ public:
 };
 
 
+/* merge stop */
+class tool_merge_stop_t : public two_click_tool_t {
+private:
+	halthandle_t halt_be_merged_from;
+	halthandle_t halt_be_merged_to;
+public:
+	tool_merge_stop_t() : two_click_tool_t(TOOL_MERGE_STOP | GENERAL_TOOL) {}
+	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("merge stop"); }
+	bool is_init_network_save() const OVERRIDE { return true; }
+private:
+	char const* do_work(player_t*, koord3d const&, koord3d const&) OVERRIDE;
+	void mark_tiles(player_t*, koord3d const&, koord3d const&) OVERRIDE;
+	uint8 is_valid_pos(player_t*, koord3d const&, char const*&, koord3d const&) OVERRIDE;
+	image_id get_marker_image() OVERRIDE;
+};
+
+
 // internal tool: show error message at specific coordinate
 // used for scenario error messages send by server
 class tool_error_message_t : public tool_t {
@@ -631,14 +648,14 @@ public:
 	char const* get_tooltip(player_t const*) const OVERRIDE { return env_t::networkmode ? translator::translate("deactivated in online mode") : translator::translate("Pause"); }
 	image_id get_icon(player_t*) const OVERRIDE { return env_t::networkmode ? IMG_EMPTY : icon; }
 	bool is_selected() const OVERRIDE { return welt->is_paused(); }
-	bool init( player_t * ) {
+	bool init( player_t * ) OVERRIDE {
 		if(  !env_t::networkmode  ) {
 			welt->set_fast_forward(0);
 			welt->set_pause( welt->is_paused()^1 );
 		}
 		return false;
 	}
-	bool exit(player_t *s ) { return init(s); }
+	bool exit(player_t *s ) OVERRIDE { return init(s); }
 	bool is_init_network_save() const OVERRIDE { return !env_t::networkmode; }
 	bool is_work_network_save() const OVERRIDE { return !env_t::networkmode; }
 };
@@ -649,7 +666,7 @@ public:
 	char const* get_tooltip(player_t const*) const OVERRIDE { return env_t::networkmode ? translator::translate("deactivated in online mode") : translator::translate("Fast forward"); }
 	image_id get_icon(player_t*) const OVERRIDE { return env_t::networkmode ? IMG_EMPTY : icon; }
 	bool is_selected() const OVERRIDE { return welt->is_fast_forward(); }
-	bool init( player_t * ) {
+	bool init( player_t * ) OVERRIDE {
 		if(  !env_t::networkmode  ) {
 			if(  welt->is_fast_forward()  &&  env_t::simple_drawing_fast_forward  ) {
 				welt->set_dirty();
@@ -659,7 +676,7 @@ public:
 		}
 		return false;
 	}
-	bool exit(player_t *s ) { return init(s); }
+	bool exit(player_t *s ) OVERRIDE { return init(s); }
 	bool is_init_network_save() const OVERRIDE { return !env_t::networkmode; }
 	bool is_work_network_save() const OVERRIDE { return !env_t::networkmode; }
 };
@@ -678,7 +695,7 @@ class tool_increase_industry_t : public tool_t {
 public:
 	tool_increase_industry_t() : tool_t(TOOL_INCREASE_INDUSTRY | SIMPLE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("Increase Industry density"); }
-	bool init( player_t * );
+	bool init( player_t * ) OVERRIDE;
 };
 
 /* prissi: undo building */
@@ -696,7 +713,7 @@ class tool_switch_player_t : public tool_t {
 public:
 	tool_switch_player_t() : tool_t(TOOL_SWITCH_PLAYER | SIMPLE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("Change player"); }
-	bool init( player_t * ) {
+	bool init( player_t * ) OVERRIDE {
 		welt->switch_active_player( welt->get_active_player_nr()+1, true );
 		return false;
 	}
@@ -710,7 +727,7 @@ class tool_step_year_t : public tool_t {
 public:
 	tool_step_year_t() : tool_t(TOOL_STEP_YEAR | SIMPLE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("Step timeline one year"); }
-	bool init( player_t * ) {
+	bool init( player_t * ) OVERRIDE {
 		welt->step_year();
 		return false;
 	}
@@ -723,7 +740,7 @@ public:
 		int factor = atoi(default_param);
 		return factor>0 ? translator::translate("Accelerate time") : translator::translate("Deccelerate time");
 	}
-	bool init( player_t *player ) {
+	bool init( player_t *player ) OVERRIDE {
 		if(  !env_t::networkmode  ||  player->is_public_service()  ) {
 			// in networkmode only for public player
 			welt->change_time_multiplier( atoi(default_param) );
@@ -756,12 +773,12 @@ public:
 	tool_show_coverage_t() : tool_t(TOOL_SHOW_COVERAGE | SIMPLE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("show station coverage"); }
 	bool is_selected() const OVERRIDE { return env_t::station_coverage_show; }
-	bool init( player_t * ) {
+	bool init( player_t * ) OVERRIDE {
 		env_t::station_coverage_show = !env_t::station_coverage_show;
 		welt->set_dirty();
 		return false;
 	}
-	bool exit(player_t *s ) { return init(s); }
+	bool exit(player_t *s ) OVERRIDE { return init(s); }
 	bool is_init_network_save() const OVERRIDE { return true; }
 	bool is_work_network_save() const OVERRIDE { return true; }
 };
@@ -774,7 +791,7 @@ public:
 			(env_t::show_names>>2)==2 ? "hide station names" :
 			(env_t::show_names&1) ? "show waiting bars" : "show station names");
 	}
-	bool init( player_t * ) {
+	bool init( player_t * ) OVERRIDE {
 		if(  env_t::show_names>=11  ) {
 			if(  (env_t::show_names&3)==3  ) {
 				env_t::show_names = 0;
@@ -804,12 +821,12 @@ public:
 	tool_show_grid_t() : tool_t(TOOL_SHOW_GRID | SIMPLE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("show grid"); }
 	bool is_selected() const OVERRIDE { return grund_t::show_grid; }
-	bool init( player_t * ) {
+	bool init( player_t * ) OVERRIDE {
 		grund_t::toggle_grid();
 		welt->set_dirty();
 		return false;
 	}
-	bool exit(player_t *s ) { return init(s); }
+	bool exit(player_t *s ) OVERRIDE { return init(s); }
 	bool is_init_network_save() const OVERRIDE { return true; }
 	bool is_work_network_save() const OVERRIDE { return true; }
 };
@@ -819,8 +836,8 @@ public:
 	tool_show_trees_t() : tool_t(TOOL_SHOW_TREES | SIMPLE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("hide trees"); }
 	bool is_selected() const OVERRIDE {return env_t::hide_trees; }
-	bool init( player_t * );
-	bool exit(player_t *s ) { return init(s); }
+	bool init( player_t * ) OVERRIDE;
+	bool exit(player_t *s ) OVERRIDE { return init(s); }
 	bool is_init_network_save() const OVERRIDE { return true; }
 	bool is_work_network_save() const OVERRIDE { return true; }
 };
@@ -833,7 +850,7 @@ public:
 			env_t::hide_buildings==0 ? "hide city building" :
 			(env_t::hide_buildings==1) ? "hide all building" : "show all building");
 	}
-	bool init( player_t * ) {
+	bool init( player_t * ) OVERRIDE {
 		env_t::hide_buildings ++;
 		if(env_t::hide_buildings>env_t::ALL_HIDDEN_BUILDING) {
 			env_t::hide_buildings = env_t::NOT_HIDE;
@@ -852,9 +869,9 @@ public:
 	char const* get_tooltip(player_t const*) const OVERRIDE;
 	bool is_selected() const OVERRIDE;
 	void draw_after(scr_coord, bool dirty) const OVERRIDE;
-	bool init( player_t * );
+	bool init( player_t * ) OVERRIDE;
 	char const* work(player_t*, koord3d) OVERRIDE;
-	bool exit(player_t * ) { return false; }
+	bool exit(player_t * ) OVERRIDE { return false; }
 	bool is_init_network_save() const OVERRIDE { return true; }
 	bool is_work_network_save() const OVERRIDE { return true; }
 };
@@ -863,7 +880,7 @@ class tool_rotate90_t : public tool_t {
 public:
 	tool_rotate90_t() : tool_t(TOOL_ROTATE90 | SIMPLE_TOOL) {}
 	image_id get_icon(player_t*) const OVERRIDE { return env_t::networkmode ? IMG_EMPTY : icon; }
-	virtual void draw_after(scr_coord pos, bool dirty) const; /* may draw a compass on top */
+	void draw_after(scr_coord pos, bool dirty) const OVERRIDE; /* may draw a compass on top */
 	char const* get_tooltip(player_t const*) const OVERRIDE { return env_t::networkmode ? translator::translate("deactivated in online mode") : translator::translate("Rotate map"); }
 	bool init( player_t * ) OVERRIDE;
 	bool is_init_network_save() const OVERRIDE { return !env_t::networkmode; }
@@ -884,8 +901,8 @@ class tool_fill_trees_t : public tool_t {
 public:
 	tool_fill_trees_t() : tool_t(TOOL_FILL_TREES | SIMPLE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("Fill trees"); }
-	image_id get_icon(player_t *) const { return baum_t::get_count() > 0 ? icon : IMG_EMPTY; }
-	bool init(player_t * ) {
+	image_id get_icon(player_t *) const OVERRIDE { return baum_t::get_count() > 0 ? icon : IMG_EMPTY; }
+	bool init(player_t * ) OVERRIDE {
 		if(  baum_t::get_count() > 0  &&  default_param  ) {
 			baum_t::fill_trees( atoi(default_param) );
 		}
@@ -898,7 +915,7 @@ class tool_daynight_level_t : public tool_t {
 public:
 	tool_daynight_level_t() : tool_t(TOOL_DAYNIGHT_LEVEL | SIMPLE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE;
-	bool init(player_t * );
+	bool init(player_t * ) OVERRIDE;
 	bool is_init_network_save() const OVERRIDE { return true; }
 	bool is_work_network_save() const OVERRIDE { return true; }
 };
@@ -907,7 +924,7 @@ class tool_vehicle_tooltips_t : public tool_t {
 public:
 	tool_vehicle_tooltips_t() : tool_t(TOOL_VEHICLE_TOOLTIPS | SIMPLE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("Toggle vehicle tooltips"); }
-	bool init( player_t * ) {
+	bool init( player_t * ) OVERRIDE {
 		env_t::show_vehicle_states = (env_t::show_vehicle_states+1)%3;
 		welt->set_dirty();
 		return false;
@@ -921,14 +938,14 @@ public:
 	tool_toggle_pax_station_t() : tool_t(TOOL_TOOGLE_PAX | SIMPLE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("5LIGHT_CHOOSE"); }
 	bool is_selected() const OVERRIDE { return welt->get_settings().get_show_pax(); }
-	bool init( player_t * ) {
+	bool init( player_t * ) OVERRIDE {
 		if( !env_t::networkmode) {
 			settings_t& s = welt->get_settings();
 			s.set_show_pax(!s.get_show_pax());
 		}
 		return false;
 	}
-	bool exit(player_t *s ) { return init(s); }
+	bool exit(player_t *s ) OVERRIDE { return init(s); }
 	bool is_init_network_save() const OVERRIDE { return false; }
 };
 
@@ -937,14 +954,14 @@ public:
 	tool_toggle_pedestrians_t() : tool_t(TOOL_TOOGLE_PEDESTRIANS | SIMPLE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("6LIGHT_CHOOSE"); }
 	bool is_selected() const OVERRIDE { return welt->get_settings().get_random_pedestrians(); }
-	bool init( player_t * ) {
+	bool init( player_t * ) OVERRIDE {
 		if( !env_t::networkmode) {
 			settings_t& s = welt->get_settings();
 			s.set_random_pedestrians(!s.get_random_pedestrians());
 		}
 		return false;
 	}
-	bool exit(player_t *s ) { return init(s); }
+	bool exit(player_t *s ) OVERRIDE { return init(s); }
 	bool is_init_network_save() const OVERRIDE { return false; }
 };
 
@@ -953,7 +970,7 @@ public:
 	tool_toggle_reservation_t() : tool_t(TOOL_TOGGLE_RESERVATION | SIMPLE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("show/hide block reservations"); }
 	bool is_selected() const OVERRIDE { return schiene_t::show_reservations; }
-	bool init( player_t * ) {
+	bool init( player_t * ) OVERRIDE {
 		schiene_t::show_reservations ^= 1;
 		welt->set_dirty();
 		return false;
@@ -967,7 +984,7 @@ public:
 	tool_view_owner_t() : tool_t(TOOL_VIEW_OWNER | SIMPLE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("show/hide object owner"); }
 	bool is_selected() const OVERRIDE { return obj_t::show_owner; }
-	bool init( player_t * ) {
+	bool init( player_t * ) OVERRIDE {
 		obj_t::show_owner ^= 1;
 		welt->set_dirty();
 		return false;
@@ -981,12 +998,12 @@ public:
 	tool_hide_under_cursor_t() : tool_t(TOOL_HIDE_UNDER_CURSOR | SIMPLE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("hide objects under cursor"); }
 	bool is_selected() const OVERRIDE { return env_t::hide_under_cursor; }
-	bool init( player_t * ) {
+	bool init( player_t * ) OVERRIDE {
 		env_t::hide_under_cursor = !env_t::hide_under_cursor  &&  env_t::cursor_hide_range>0;
 		welt->set_dirty();
 		return false;
 	}
-	bool exit(player_t *s ) { return init(s); }
+	bool exit(player_t *s ) OVERRIDE { return init(s); }
 	bool is_init_network_save() const OVERRIDE { return true; }
 	bool is_work_network_save() const OVERRIDE { return true; }
 };
@@ -998,7 +1015,7 @@ public:
 	tool_traffic_level_t() : tool_t(TOOL_TRAFFIC_LEVEL | SIMPLE_TOOL) {}
 	char const* get_tooltip(player_t const*) const OVERRIDE { return translator::translate("6WORLD_CHOOSE"); }
 	bool is_selected() const OVERRIDE { return false; }
-	bool init( player_t * ) {
+	bool init( player_t * ) OVERRIDE {
 		assert(  default_param  );
 		sint16 level = min( max( atoi(default_param), 0), 16);
 		welt->get_settings().set_traffic_level(level);
