@@ -60,7 +60,6 @@
 #include "tool_selector.h"
 #include "player_frame_t.h"
 #include "money_frame.h"
-#include "halt_detail.h"
 #include "halt_info.h"
 #include "convoi_detail_t.h"
 #include "convoi_info_t.h"
@@ -75,11 +74,14 @@
 #include "goods_frame_t.h"
 #include "loadfont_frame.h"
 #include "scenario_info.h"
+#include "depot_frame.h"
 
 #include "../simversion.h"
 
 class inthashtable_tpl<ptrdiff_t,scr_coord> old_win_pos;
 
+// hash-table: magic number to windowsize
+class inthashtable_tpl<ptrdiff_t, scr_size> saved_windowsizes;
 
 #define dragger_size 12
 
@@ -182,7 +184,7 @@ static int display_gadget_box(sint8 code,
 
 	if(pushed) {
 		// mark_rect_dirty_wc(x, y, D_GADGET_WIDTH, D_TITLEBAR_HEIGHT);
-		display_fillbox_wh_rgb(x, y, D_GADGET_WIDTH, D_TITLEBAR_HEIGHT, lighter, false);
+		display_fillbox_wh_clip_rgb(x, y, D_GADGET_WIDTH, D_TITLEBAR_HEIGHT, lighter, false);
 	}
 
 	// Do we have a gadget image?
@@ -212,8 +214,8 @@ static int display_gadget_box(sint8 code,
 	}
 
 	int side = x+REVERSE_GADGETS*D_GADGET_WIDTH-1;
-	display_vline_wh_rgb(side+1, y+1, D_TITLEBAR_HEIGHT-2, lighter, false);
-	display_vline_wh_rgb(side,   y+1, D_TITLEBAR_HEIGHT-2, darker,  false);
+	display_vline_wh_clip_rgb(side+1, y+1, D_TITLEBAR_HEIGHT-2, lighter, false);
+	display_vline_wh_clip_rgb(side,   y+1, D_TITLEBAR_HEIGHT-2, darker,  false);
 
 	// Hajo: return width of gadget
 	return D_GADGET_WIDTH;
@@ -332,18 +334,18 @@ static void win_draw_window_title(const scr_coord pos, const scr_size size,
 		const bool goto_pushed,
 		simwin_gadget_flags_t &flags )
 {
-	PUSH_CLIP(pos.x, pos.y, size.w, size.h);
+	PUSH_CLIP_FIT(pos.x, pos.y, size.w, size.h);
 
 	PIXVAL lighter = display_blend_colors(title_color, color_idx_to_rgb(COL_WHITE), 25);
 	PIXVAL darker  = display_blend_colors(title_color, color_idx_to_rgb(COL_BLACK), 25);
 
 	display_fillbox_wh_clip_rgb(pos.x, pos.y, size.w, D_TITLEBAR_HEIGHT, title_color, false);
 
-	display_fillbox_wh_rgb( pos.x + 1, pos.y,                         size.w - 2, 1, lighter, false );
-	display_fillbox_wh_rgb( pos.x + 1, pos.y + D_TITLEBAR_HEIGHT - 1, size.w - 2, 1, darker,  false );
+	display_fillbox_wh_clip_rgb( pos.x + 1, pos.y,                         size.w - 2, 1, lighter, false );
+	display_fillbox_wh_clip_rgb( pos.x + 1, pos.y + D_TITLEBAR_HEIGHT - 1, size.w - 2, 1, darker,  false );
 
-	display_vline_wh_rgb( pos.x,              pos.y, D_TITLEBAR_HEIGHT, lighter, false );
-	display_vline_wh_rgb( pos.x + size.w - 1, pos.y, D_TITLEBAR_HEIGHT, darker,  false );
+	display_vline_wh_clip_rgb( pos.x,              pos.y, D_TITLEBAR_HEIGHT, lighter, false );
+	display_vline_wh_clip_rgb( pos.x + size.w - 1, pos.y, D_TITLEBAR_HEIGHT, darker,  false );
 
 	// Draw the gadgets and then move left and draw text.
 	flags.gotopos = (welt_pos != koord3d::invalid);
@@ -371,12 +373,97 @@ static void win_draw_window_dragger(scr_coord pos, scr_size size)
 	}
 	else {
 		for(  int x=0;  x<dragger_size;  x++  ) {
-			display_fillbox_wh_rgb( pos.x-x, pos.y-dragger_size+x, x, 1, color_idx_to_rgb((x & 1) ? COL_BLACK : MN_GREY4), true);
+			display_fillbox_wh_clip_rgb( pos.x-x, pos.y-dragger_size+x, x, 1, color_idx_to_rgb((x & 1) ? COL_BLACK : MN_GREY4), true);
 		}
 	}
 }
 
+// Functions to save & restore windowsize
 
+ptrdiff_t guess_magic_number(simwin_t *win, ptrdiff_t magic = magic_none)
+{
+	if (win) {
+		magic = win->magic_number;
+	}
+	// reduce player-wise magic numbers and magic numbers derived from handles
+	const ptrdiff_t magic_pl[] = {
+		magic_finances_t, magic_convoi_list, magic_convoi_list_filter, magic_line_list, magic_halt_list,
+		magic_line_management_t, magic_ai_options_t, magic_ai_selector, magic_pwd_t, magic_jump, magic_headquarter, magic_headquarter + MAX_PLAYER_COUNT,
+		magic_none,
+		magic_convoi_info, magic_halt_info, magic_toolbar,
+	};
+
+	for (uint i=1; i<lengthof(magic_pl); i++) {
+		if (magic_pl[i-1] == magic_none) {
+			continue;
+		}
+		if (magic_pl[i-1] <= magic  &&  magic < magic_pl[i]) {
+			return magic_pl[i-1];
+		}
+	}
+	if (win == NULL) {
+		return magic;
+	}
+	// try rdwr_id
+	uint32 id = win->gui->get_rdwr_id();
+	if (id != magic_reserved) {
+		return id;
+	}
+
+	// anything outside the magic number's ranges will be ignored
+	if (magic <= magic_reserved  ||  magic >= magic_max) {
+		magic = magic_none;
+	}
+	return magic;
+}
+
+void save_windowsize(simwin_t *win)
+{
+	ptrdiff_t magic = guess_magic_number(win);
+	if (magic != magic_none) {
+		saved_windowsizes.set(magic, win->gui->get_windowsize() );
+	}
+}
+
+scr_size get_stored_windowsize(simwin_t *win)
+{
+	ptrdiff_t magic = guess_magic_number(win);
+	if (magic != magic_none) {
+		return saved_windowsizes.get(magic);
+	}
+	return scr_size();
+}
+
+void rdwr_win_settings(loadsave_t *file)
+{
+	if (file->is_loading()) {
+		saved_windowsizes.clear();
+		sint64 magic;
+		do {
+			file->rdwr_longlong(magic);
+			if (magic != magic_none) {
+				scr_size s;
+				file->rdwr_long(s.w);
+				file->rdwr_long(s.h);
+				// ignore stuff that will not be used anymore
+				if (magic == guess_magic_number(NULL, magic)) {
+					saved_windowsizes.put(magic, s);
+				}
+			}
+		} while (magic != magic_none);
+	}
+	else {
+		typedef inthashtable_tpl<ptrdiff_t, scr_size> stupid_table_t;
+		FOR(stupid_table_t, it, saved_windowsizes) {
+			sint64 m = it.key;
+			file->rdwr_longlong(m);
+			file->rdwr_long(it.value.w);
+			file->rdwr_long(it.value.h);
+		}
+		sint64 m = magic_none;
+		file->rdwr_longlong(m);
+	}
+}
 //=========================================================================
 
 
@@ -469,7 +556,7 @@ bool win_is_top(const gui_frame_t *ig)
 // save/restore all dialogues
 void rdwr_all_win(loadsave_t *file)
 {
-	if(  file->get_version()>102003  ) {
+	if(  file->is_version_atleast(120, 8)  ) {
 		if(  file->is_saving()  ) {
 			FOR(vector_tpl<simwin_t>, & i, wins) {
 				uint32 id = i.gui->get_rdwr_id();
@@ -492,17 +579,15 @@ void rdwr_all_win(loadsave_t *file)
 				file->rdwr_long(id);
 				// create the matching
 				gui_frame_t *w = NULL;
-				switch(id) {
+				switch(magic_numbers(id)) {
 
 					// end of dialogues
 					case magic_none: return;
 
 					// actual dialogues to restore
 					case magic_convoi_info:    w = new convoi_info_t(); break;
-					case magic_convoi_detail:  w = new convoi_detail_t(); break;
 					case magic_themes:         w = new themeselector_t(); break;
 					case magic_halt_info:      w = new halt_info_t(); break;
-					case magic_halt_detail:    w = new halt_detail_t(); break;
 					case magic_reliefmap:      w = new map_frame_t(); break;
 					case magic_ki_kontroll_t:  w = new ki_kontroll_t(); break;
 					case magic_schedule_rdwr_dummy: w = new schedule_gui_t(); break;
@@ -514,6 +599,7 @@ void rdwr_all_win(loadsave_t *file)
 					case magic_goodslist:      w = new goods_frame_t(); break;
 					case magic_font:           w = new loadfont_frame_t(); break;
 					case magic_scenario_info:  w = new scenario_info_t(); break;
+					case magic_depot:          w = new depot_frame_t(); break;
 
 					default:
 						if(  id>=magic_finances_t  &&  id<magic_finances_t+MAX_PLAYER_COUNT  ) {
@@ -657,6 +743,32 @@ int create_win(int x, int y, gui_frame_t* const gui, wintype const wt, ptrdiff_t
 		gui->infowin_event(&ev);
 		inside_event_handling = old;
 
+		// restore windowsize
+		scr_size stored = get_stored_windowsize(&win);
+
+		if (stored == scr_size()) {
+			// not stored, take current
+			stored = gui->get_windowsize();
+		}
+		// use default width
+		stored.clip_lefttop(scr_size(D_DEFAULT_WIDTH, D_DEFAULT_HEIGHT));
+		// clip to display size
+		stored.clip_rightbottom( scr_size(display_get_width(), display_get_height() - env_t::iconsize.h - win_get_statusbar_height() ) );
+
+		if (stored != gui->get_windowsize()) {
+			// send tailored resize event
+			scr_size delta = stored - gui->get_windowsize();
+			event_t wev;
+			wev.ev_class = WINDOW_RESIZE;
+			wev.ev_code = 0;
+			wev.mx = delta.w;
+			wev.my = delta.h;
+
+			inside_event_handling = gui;
+			gui->infowin_event(&wev);
+			inside_event_handling = old;
+		}
+
 		scr_size size = gui->get_windowsize();
 
 		if(x == -1) {
@@ -695,6 +807,9 @@ int create_win(int x, int y, gui_frame_t* const gui, wintype const wt, ptrdiff_t
 		return wins.get_count();
 	}
 	else {
+		if(  !( wt & w_do_not_delete )  ) {
+			delete gui;
+		}
 		return -1;
 	}
 }
@@ -726,6 +841,9 @@ static bool destroy_framed_win(simwin_t *wins)
 	const scr_size size = wins->gui->get_windowsize();
 	mark_rect_dirty_wc( wins->pos.x - 1, wins->pos.y - 1, wins->pos.x + size.w + 2, wins->pos.y + size.h + 2 ); // -1, +2 for env_t::window_frame_active
 
+	// save windowsize for later
+	save_windowsize(wins);
+
 	gui_frame_t* gui = wins->gui; // save pointer to gui window: might be modified in event handling, or could be modified if wins points to value in kill_list and kill_list is modified! nasty surprise
 	if(  gui  ) {
 		event_t ev;
@@ -917,10 +1035,10 @@ void display_win(int win)
 	if(env_t::window_frame_active  &&  (unsigned)win==wins.get_count()-1) {
 		const int y_off = wins[win].flags.title ? 0 : D_TITLEBAR_HEIGHT;
 		if(!wins[win].rollup) {
-			display_ddd_box_rgb( wins[win].pos.x-1, wins[win].pos.y-1 + y_off, size.w+2, size.h+2 - y_off, title_color, title_color, wins[win].dirty | wins[win].gui->is_dirty() );
+			display_ddd_box_clip_rgb( wins[win].pos.x-1, wins[win].pos.y-1 + y_off, size.w+2, size.h+2 - y_off, title_color, title_color); //, wins[win].dirty | wins[win].gui->is_dirty() );
 		}
 		else {
-			display_ddd_box_rgb( wins[win].pos.x-1, wins[win].pos.y-1 + y_off, size.w+2, D_TITLEBAR_HEIGHT + 2 - y_off, title_color, title_color, wins[win].dirty | wins[win].gui->is_dirty() );
+			display_ddd_box_clip_rgb( wins[win].pos.x-1, wins[win].pos.y-1 + y_off, size.w+2, D_TITLEBAR_HEIGHT + 2 - y_off, title_color, title_color); //, wins[win].dirty | wins[win].gui->is_dirty() );
 		}
 	}
 	if(!wins[win].rollup) {
@@ -985,7 +1103,7 @@ static void remove_old_win()
 }
 
 
-static inline void snap_check_distance( sint16 *r, const sint16 a, const sint16 b )
+static inline void snap_check_distance( scr_coord_val *r, const scr_coord_val a, const scr_coord_val b )
 {
 	if(  abs(a-b)<=env_t::window_snap_distance  ) {
 		*r = a;
@@ -1022,9 +1140,9 @@ void snap_check_win( const int win, scr_coord *r, const scr_coord from_pos, cons
 			other_pos.x = 0;
 			other_pos.y = env_t::iconsize.h;
 			other_size.x = display_get_width();
-			other_size.y = display_get_height()-16-other_pos.y; // 16 = bottom ticker height?
+			other_size.y = display_get_height()-win_get_statusbar_height()-other_pos.y;
 			if(  show_ticker  ) {
-				other_size.y -= 16;
+				other_size.y -= TICKER_HEIGHT;
 			}
 		}
 		else {
@@ -1123,7 +1241,7 @@ void move_win(int win, event_t *ev)
 
 	// CLIP(wert,min,max)
 	to_pos.x = CLIP( to_pos.x, 8-to_size.x, display_get_width()-16 );
-	to_pos.y = CLIP( to_pos.y, env_t::iconsize.h, display_get_height()-24 );
+	to_pos.y = CLIP( to_pos.y, env_t::iconsize.h, display_get_height() - D_TITLEBAR_HEIGHT - win_get_statusbar_height() - TICKER_HEIGHT);
 
 	// delta is actual window movement.
 	const scr_coord delta = to_pos - from_pos;
@@ -1291,13 +1409,13 @@ bool check_pos_win(event_t *ev)
 	}
 
 	// swallow all other events in the infobar
-	if(  !(ev->ev_class == EVENT_KEYBOARD  ||  ev->ev_class == EVENT_STRING)  &&  y > display_get_height()-16  ) {
+	if(  !(ev->ev_class == EVENT_KEYBOARD  ||  ev->ev_class == EVENT_STRING)  &&  y > display_get_height()- win_get_statusbar_height()  ) {
 		// swallow event
 		return true;
 	}
 
 	// swallow all other events in ticker (if there)
-	if(  !(ev->ev_class == EVENT_KEYBOARD  ||  ev->ev_class == EVENT_STRING)  &&  show_ticker  &&  y > display_get_height()-32  ) {
+	if(  !(ev->ev_class == EVENT_KEYBOARD  ||  ev->ev_class == EVENT_STRING)  &&  show_ticker  &&  y > display_get_height()- win_get_statusbar_height() - TICKER_HEIGHT  ) {
 		if(  IS_LEFTCLICK(ev)  ) {
 			// goto infowin koordinate, if ticker is active
 			koord p = ticker::get_welt_pos();
@@ -1450,7 +1568,7 @@ void win_poll_event(event_t* const ev)
 	if(  ev->ev_class==EVENT_SYSTEM  &&  ev->ev_code==SYSTEM_RESIZE  ) {
 		// main window resized
 		simgraph_resize( ev->size_x, ev->size_y );
-		ticker::redraw_ticker();
+		ticker::redraw();
 		wl->set_dirty();
 		wl->get_viewport()->metrics_updated();
 		ev->ev_class = EVENT_NONE;
@@ -1469,8 +1587,18 @@ void win_poll_event(event_t* const ev)
 				rdwr_all_win( &dlg );
 			}
 		}
+		wl->set_dirty();
 		ev->ev_class = EVENT_NONE;
-		ticker::redraw_ticker();
+		ticker::redraw();
+	}
+	if(  ev->ev_class==EVENT_SYSTEM  &&  ev->ev_code==SYSTEM_THEME_CHANGED  ) {
+		// called when font is changed
+		ev->mx = ev->my = ev->cx = ev->cy = 0;
+		FOR(vector_tpl<simwin_t>, const& i, wins) {
+			i.gui->infowin_event(ev);
+		}
+		ev->ev_class = EVENT_NONE;
+		ticker::redraw();
 	}
 }
 
@@ -1522,30 +1650,26 @@ void win_display_flush(double konto)
 	display_set_clip_wh( 0, menu_height, disp_width, disp_height-menu_height+1 );
 
 	show_ticker = false;
-	if( !ticker::empty() ) {
-		ticker::draw();
-		if (ticker::empty()) {
-			// set dirty background for removing ticker
-			if(wl) {
-				wl->set_background_dirty();
-			}
-		}
-		else {
-			show_ticker = true;
-			// need to adapt tooltip_y coordinates
-			tooltip_ypos = min(tooltip_ypos, disp_height-15-10-16);
+	ticker::draw();
+	if (ticker::empty()) {
+		// set dirty background for removing ticker
+		if(wl) {
+			wl->set_background_dirty();
 		}
 	}
+	else {
+		show_ticker = true;
+		// need to adapt tooltip_y coordinates
+		tooltip_ypos = min(tooltip_ypos, disp_height-15-10-16);
+	}
 
 	if(  skinverwaltung_t::compass_iso  &&  env_t::compass_screen_position  ) {
 		display_img_aligned( skinverwaltung_t::compass_iso->get_image_id( wl->get_settings().get_rotation() ), scr_rect(4,menu_height+4,disp_width-2*4,disp_height-menu_height-15-2*4-(TICKER_HEIGHT)*show_ticker), env_t::compass_screen_position, false );
 	}
 
-	// ok, we want to clip the height for everything!
-	// unfortunately, the easiest way is by manipulating the global high
 	{
-		sint16 oldh = display_get_height();
-		display_set_height( oldh-(wl?16:0)-(TICKER_HEIGHT)*show_ticker );
+		// clip windows to avoid drawing into menu, ticker, or status-bar
+		PUSH_CLIP(0, menu_height, display_get_width(), display_get_height() - menu_height - (TICKER_HEIGHT)*show_ticker - win_get_statusbar_height() );
 
 		display_all_win();
 		remove_old_win();
@@ -1579,7 +1703,7 @@ void win_display_flush(double konto)
 			tooltip_text = 0;
 		}
 
-		display_set_height( oldh );
+		POP_CLIP();
 
 		if(!wl) {
 			// no infos during loading etc
@@ -1733,6 +1857,28 @@ bool win_change_zoom_factor(bool magnify)
 }
 
 
+void win_load_font(const char *fname, uint16 fontsize)
+{
+	bool force_reload = fontsize != env_t::fontsize;
+	env_t::fontsize = fontsize;
+
+	if (display_load_font(fname, force_reload) ) {
+		// successfull
+		gui_theme_t::themes_init( env_t::default_theme, false );
+
+		event_t *ev = new event_t();
+		ev->ev_class = EVENT_SYSTEM;
+		ev->ev_code = SYSTEM_THEME_CHANGED;
+		queue_event( ev );
+	}
+	else {
+		// restore old font
+		display_load_font(env_t::fontname.c_str(), true);
+	}
+	win_redraw_world();
+}
+
+
 /**
  * Sets the tooltip to display.
  * Has to be called from within gui_frame_t::draw
