@@ -52,18 +52,18 @@ enum magic_numbers {
 	magic_sound_kontroll_t,
 	magic_load_t,
 	magic_save_t,
-	magic_railtools,
-	magic_monorailtools,
-	magic_tramtools, // Dario: Tramway
-	magic_roadtools,
-	magic_shiptools,
-	magic_airtools,
-	magic_specialtools,
-	magic_listtools,
-	magic_edittools,
-	magic_slopetools,
+	magic_UNUSED_railtools,
+	magic_UNUSED_monorailtools,
+	magic_UNUSED_tramtools, // Dario: Tramway
+	magic_UNUSED_roadtools,
+	magic_UNUSED_shiptools,
+	magic_UNUSED_airtools,
+	magic_UNUSED_specialtools,
+	magic_UNUSED_listtools,
+	magic_UNUSED_edittools,
+	magic_UNUSED_slopetools,
 	magic_halt_list_t,
-	magic_label_frame,
+	magic_UNUSED_label_frame,
 	magic_city_info_t,
 	magic_citylist_frame_t,
 	magic_mainhelp,
@@ -77,8 +77,9 @@ enum magic_numbers {
 	magic_ai_options_t=magic_line_management_t+MAX_PLAYER_COUNT,
 	magic_ai_selector=magic_ai_options_t+MAX_PLAYER_COUNT,
 	magic_pwd_t=magic_ai_selector+MAX_PLAYER_COUNT,
-	// normal stuff
 	magic_jump=magic_pwd_t+MAX_PLAYER_COUNT,
+	magic_headquarter = magic_jump + MAX_PLAYER_COUNT,
+	// normal stuff
 	magic_curiositylist,
 	magic_factorylist,
 	magic_goodslist,
@@ -98,15 +99,18 @@ enum magic_numbers {
 	magic_schedule_rdwr_dummy,	// only used to save/load schedules
 	magic_line_schedule_rdwr_dummy,	// only used to save/load line schedules
 	magic_motd,
-	magic_convoi_info,
-	magic_factory_info,
+	magic_factory_info, // only used to load/save
 	magic_font,
-	magic_convoi_detail=magic_convoi_info+65536,
-	magic_halt_info=magic_convoi_detail+65536,
-	magic_halt_detail=magic_halt_info+65536,
-	magic_toolbar=magic_halt_detail+65536,
-	magic_info_pointer=magic_toolbar+256,
-	magic_max = magic_info_pointer+843
+	// magic numbers with big jumps between them
+	magic_convoi_info,
+	magic_UNUSED_convoi_detail=magic_convoi_info+65536, // unused range
+	magic_halt_info=magic_UNUSED_convoi_detail +65536,
+	magic_UNUSED_halt_detail=magic_halt_info+65536, // unused range
+	magic_toolbar=magic_UNUSED_halt_detail+65536,
+	magic_script_error=magic_toolbar+256,
+	magic_haltlist_filter,
+	magic_depot, // only used to load/save
+	magic_max
 };
 
 // Holding time for auto-closing windows
@@ -117,6 +121,9 @@ void init_map_win();
 // windows with a valid id can be saved and restored
 void rdwr_all_win(loadsave_t *file);
 
+// save windowsizes in settings
+void rdwr_win_settings(loadsave_t *file);
+
 int create_win(gui_frame_t*, wintype, ptrdiff_t magic);
 int create_win(int x, int y, gui_frame_t*, wintype, ptrdiff_t magic);
 
@@ -178,6 +185,11 @@ void win_set_world(karte_t *world);
  */
 void win_redraw_world();
 
+/**
+ * Loads new font. Notifies gui's, world.
+ */
+void win_load_font(const char *fname, uint16 fontsize);
+
 /**
  * Sets the tooltip to display.
  * @param owner : owner==NULL disables timing (initial delay and visible duration)
