@@ -21,45 +21,40 @@
 class sound_frame_t : public gui_frame_t, action_listener_t
 {
 private:
-    scrollbar_t sound_volume_scrollbar;
-    scrollbar_t music_volume_scrollbar;
-    gui_label_t sound_volume_label;
-    gui_label_t music_volume_label;
-    button_t sound_mute_button;
-    button_t music_mute_button;
-    button_t next_song_button;
-    button_t previous_song_button;
-    button_t shuffle_song_button;
-    gui_label_t song_name_label;
-    gui_label_t current_playing_label;
+	scrollbar_t sound_volume_scrollbar;
+	scrollbar_t music_volume_scrollbar;
+	button_t sound_mute_button;
+	button_t music_mute_button;
+	button_t next_song_button;
+	button_t previous_song_button;
+	button_t shuffle_song_button;
+	gui_label_buf_t song_name_label;
 
-
-    char song_buf[128];
-    const char *make_song_name();
+	void update_song_name();
 
 public:
 
-    /**
+	/**
 	 * Set the window associated helptext
 	 * @return the filename for the helptext, or NULL
-     * @author Hj. Malthaner
-     */
-    const char * get_help_filename() const {return "sound.txt";}
+	 * @author Hj. Malthaner
+	 */
+	const char * get_help_filename() const OVERRIDE {return "sound.txt";}
 
 
-    /**
+	/**
 	 * Constructor. Adds all necessary Subcomponents.
-     * @author Hj. Malthaner
-     */
+	 * @author Hj. Malthaner
+	 */
     sound_frame_t();
 
-    /**
+	/**
 	 * Draw new component. The values to be passed refer to the window
 	 * i.e. It's the screen coordinates of the window where the
 	 * component is displayed.
-     * @author Hj. Malthaner
-     */
-    void draw(scr_coord pos, scr_size size);
+	 * @author Hj. Malthaner
+	 */
+	void draw(scr_coord pos, scr_size size) OVERRIDE;
 
 	bool action_triggered(gui_action_creator_t*, value_t) OVERRIDE;
 };
