@@ -10,8 +10,6 @@
 #include "components/action_listener.h"
 #include "components/gui_button.h"
 #include "components/gui_textarea.h"
-#include "components/gui_image.h"
-#include "components/gui_divider.h"
 #include "../utils/cbuffer_t.h"
 
 #include "../tpl/vector_tpl.h"
@@ -21,14 +19,12 @@ class sprachengui_t : public gui_frame_t, private action_listener_t
 private:
 	cbuffer_t buf;
 	gui_textarea_t text_label;
-	gui_image_t flags;
 
 	struct language_button_t {
 		button_t* button;
 		int id;
 	};
 	vector_tpl<language_button_t> buttons;
-	gui_divider_t seperator;
 
 	static int cmp_language_button(sprachengui_t::language_button_t a, sprachengui_t::language_button_t b);
 
@@ -42,14 +38,12 @@ public:
 
 	sprachengui_t();
 
-	~sprachengui_t();
-
 	/**
 	 * Set the window associated helptext
 	 * @return the filename for the helptext, or NULL
 	 * @author Hj. Malthaner
 	 */
-	const char *get_help_filename() const {return "language.txt";}
+	const char *get_help_filename() const OVERRIDE {return "language.txt";}
 
 	bool action_triggered(gui_action_creator_t*, value_t) OVERRIDE;
 };
