@@ -89,7 +89,8 @@ void tabfileobj_t::clear()
 
 
 // private helps to get x y value pairs needed for koord etc.
-bool tabfileobj_t::get_x_y( const char *key, sint16 &x, sint16 &y )
+template<class I>
+bool tabfileobj_t::get_x_y( const char *key, I &x, I &y )
 {
 	const char *value = get_string(key,NULL);
 	const char *tmp;
@@ -289,7 +290,7 @@ void tabfileobj_t::unused( const char *exclude_start_chars )
 }
 
 
-bool tabfile_t::read(tabfileobj_t &objinfo)
+bool tabfile_t::read(tabfileobj_t &objinfo, FILE *fp)
 {
 	bool lines = false;
 	char line[4096];
@@ -439,10 +440,16 @@ bool tabfile_t::read(tabfileobj_t &objinfo)
 
 						printf("%s = %s\n", line_expand, delim_expand);
 						objinfo.put(line_expand, delim_expand);
+						if (fp != NULL) {
+							fprintf(fp, "%s=%s\n", line_expand, delim_expand);
+						}
 					}
 				}
 				else {
 					objinfo.put(line, delim);
+					if (fp != NULL) {
+						fprintf(fp, "%s=%s\n", line, delim);
+					}
 				}
 				lines = true;
 			}
