@@ -531,7 +531,7 @@ void translator::set_language(int lang)
 		env_t::language_iso = langs[lang].iso;
 		env_t::default_settings.set_name_language_iso( langs[lang].iso );
 		init_custom_names(lang);
-		current_langinfo->eclipse_width = proportional_string_width( translate("...") );
+		current_langinfo->ellipsis_width = proportional_string_width( translate("...") );
 		DBG_MESSAGE("translator::set_language()", "%s, unicode %d", langs[lang].name, true);
 	}
 	else {
@@ -596,6 +596,102 @@ const char *translator::get_month_name(uint16 month)
 	return translate(month_names[month % lengthof(month_names)]);
 }
 
+const char *translator::get_short_month_name(uint16 month)
+{
+	static const char *const short_month_names[] = {
+		"Jan.",
+		"Feb.",
+		"Mar.",
+		"Apr.",
+		"May",
+		"June",
+		"July",
+		"Aug.",
+		"Sept.",
+		"Oct.",
+		"Nov.",
+		"Dec."
+	};
+	return translate(short_month_names[month % lengthof(short_month_names)]);
+}
+
+const char *translator::get_date(uint16 year, uint16 month)
+{
+	char const* const month_ = get_month_name(month);
+	char const* const year_sym = strcmp("YEAR_SYMBOL", translate("YEAR_SYMBOL")) ? translate("YEAR_SYMBOL") : "";
+	static char sdate[256];
+	switch (env_t::show_month) {
+		case env_t::DATE_FMT_JAPANESE:
+		case env_t::DATE_FMT_JAPANESE_NO_SEASON:
+			sprintf(sdate, "%4d%s %s", year, year_sym, month_);
+			break;
+		case env_t::DATE_FMT_GERMAN:
+		case env_t::DATE_FMT_GERMAN_NO_SEASON:
+		case env_t::DATE_FMT_US:
+		case env_t::DATE_FMT_US_NO_SEASON:
+		default:
+			sprintf(sdate, "%s %4d%s", month_, year, year_sym);
+			break;
+	}
+	return sdate;
+}
+
+const char *translator::get_date(uint16 year, uint16 month, uint16 day, char const* season)
+{
+	char const* const month_ = get_month_name(month);
+	char const* const year_sym = strcmp("YEAR_SYMBOL", translate("YEAR_SYMBOL")) ? translate("YEAR_SYMBOL") : "";
+	char const* const day_sym = strcmp("DAY_SYMBOL", translate("DAY_SYMBOL")) ? translate("DAY_SYMBOL") : "";
+	static char date[256];
+	switch(env_t::show_month) {
+		case env_t::DATE_FMT_GERMAN:
+			sprintf(date, "%s %d. %s %d%s", season, day, month_, year, year_sym);
+			break;
+		case env_t::DATE_FMT_GERMAN_NO_SEASON:
+			sprintf(date, "%d. %s %d%s", day, month_, year, year_sym);
+			break;
+		case env_t::DATE_FMT_US:
+			sprintf(date, "%s %s %d %d%s", season, month_, day, year, year_sym);
+			break;
+		case env_t::DATE_FMT_US_NO_SEASON:
+			sprintf(date, "%s %d %d%s", month_, day, year, year_sym);
+			break;
+		case env_t::DATE_FMT_JAPANESE:
+			sprintf(date, "%s %d%s %s %d%s", season, year, year_sym, month_, day, day_sym);
+			break;
+		case env_t::DATE_FMT_JAPANESE_NO_SEASON:
+			sprintf(date, "%d%s %s %d%s", year, year_sym, month_, day, day_sym);
+			break;
+		case env_t::DATE_FMT_MONTH:
+			sprintf(date, "%s, %s %d%s", month_, season, year, year_sym);
+			break;
+		case env_t::DATE_FMT_SEASON:
+			sprintf(date, "%s %d%s", season, year, year_sym);
+			break;
+	}
+	return date;
+}
+
+const char *translator::get_short_date(uint16 year, uint16 month)
+{
+	char const* const month_ = get_short_month_name(month);
+	char const* const year_sym = strcmp("YEAR_SYMBOL", translate("YEAR_SYMBOL")) ? translate("YEAR_SYMBOL") : "";
+	static char sdate[256];
+	switch (env_t::show_month) {
+		case env_t::DATE_FMT_JAPANESE:
+		case env_t::DATE_FMT_JAPANESE_NO_SEASON:
+			sprintf(sdate, "%4d%s %s", year, year_sym , month_);
+			break;
+		case env_t::DATE_FMT_GERMAN:
+		case env_t::DATE_FMT_GERMAN_NO_SEASON:
+		case env_t::DATE_FMT_US:
+		case env_t::DATE_FMT_US_NO_SEASON:
+		default:
+			sprintf(sdate, "%s %4d%s", month_, year, year_sym);
+			break;
+	}
+	return sdate;
+}
+
 
 /* get a name for a non-matching object */
 const char *translator::compatibility_name(const char *str)
