@@ -11,7 +11,7 @@
 
 #include "tunnelbauer.h"
 
-#include "../gui/karte.h"
+#include "../gui/minimap.h"
 
 #include "../simworld.h"
 #include "../player/simplay.h"
@@ -49,7 +49,7 @@ void tunnel_builder_t::register_desc(tunnel_desc_t *desc)
 		dbg->doubled( "tunnel", desc->get_name() );
 		tool_t::general_tool.remove( old_desc->get_builder() );
 		delete old_desc->get_builder();
-//		delete old_desc; becasue deleting PowerTunnel seems to corrupt memprz, and the small memory loss in not reallz worth the troubles
+//		delete old_desc; because deleting PowerTunnel seems to corrupt memory, and the small memory loss in not really worth the troubles
 	}
 	// add the tool
 	tool_build_tunnel_t *tool = new tool_build_tunnel_t();
@@ -618,7 +618,7 @@ void tunnel_builder_t::build_tunnel_portal(player_t *player, koord3d end, koord
 	if( ground_outside) {
 		weg_t *way_outside = ground_outside->get_weg( desc->get_waytype() );
 		if( way_outside ) {
-			// use the check_owner routine of way_builder_t (not spieler_t!), needs an instance
+			// use the check_owner routine of way_builder_t (not player_t!), needs an instance
 			way_builder_t bauigel(player);
 			bauigel.init_builder( (way_builder_t::bautyp_t)desc->get_waytype(), way_outside->get_desc());
 			sint32 dummy;
@@ -720,7 +720,7 @@ const char *tunnel_builder_t::remove(player_t *player, koord3d start, waytype_t
 		welt->access(pos.get_2d())->boden_entfernen(gr);
 		delete gr;
 
-		reliefkarte_t::get_karte()->calc_map_pixel( pos.get_2d() );
+		minimap_t::get_instance()->calc_map_pixel( pos.get_2d() );
 	}
 
 	// Und die Tunnelenden am Schlu
