@@ -32,9 +32,9 @@ public:
 	 */
 	monorail_t(loadsave_t *file);
 
-	virtual waytype_t get_waytype() const {return monorail_wt;}
+	waytype_t get_waytype() const OVERRIDE {return monorail_wt;}
 
-	void rdwr(loadsave_t *file);
+	void rdwr(loadsave_t *file) OVERRIDE;
 };
 
 #endif
