@@ -25,9 +25,9 @@ public:
 	 */
 	narrowgauge_t(loadsave_t *file);
 
-	virtual waytype_t get_waytype() const {return narrowgauge_wt;}
+	waytype_t get_waytype() const OVERRIDE {return narrowgauge_wt;}
 
-	void rdwr(loadsave_t *file);
+	void rdwr(loadsave_t *file) OVERRIDE;
 };
 
 #endif
