@@ -9,6 +9,8 @@
 #include "../../bauer/wegbauer.h"
 #include "../../descriptor/way_desc.h"
 #include "../../dataobj/loadsave.h"
+#include "../../dataobj/translator.h"
+#include "../../utils/cbuffer_t.h"
 
 #include "runway.h"
 
@@ -27,6 +29,18 @@ runway_t::runway_t(loadsave_t *file) : schiene_t()
 }
 
 
+void runway_t::info(cbuffer_t & buf) const
+{
+	schiene_t::info(buf);
+
+	cbuffer_t reserved;
+	if(  get_desc()->get_styp()==type_runway  ) {
+		reserved.printf( "%s %i\n", translator::translate("waiting"), reservations.get_count() );
+		buf.append( reserved );
+	}
+}
+
+
 void runway_t::rdwr(loadsave_t *file)
 {
 	xml_tag_t t( file, "runway_t" );
