@@ -28,16 +28,16 @@ public:
 	wolke_t(koord3d pos, sint8 xoff, sint8 yoff, const skin_desc_t *cloud );
 	~wolke_t();
 
-	sync_result sync_step(uint32 delta_t);
+	sync_result sync_step(uint32 delta_t) OVERRIDE;
 
-	const char* get_name() const { return "Wolke"; }
-	typ get_typ() const { return sync_wolke; }
+	const char* get_name() const OVERRIDE { return "Wolke"; }
+	typ get_typ() const OVERRIDE { return sync_wolke; }
 
-	image_id get_image() const;
+	image_id get_image() const OVERRIDE;
 
-	void rdwr(loadsave_t *file);
+	void rdwr(loadsave_t *file) OVERRIDE;
 
-	virtual void rotate90();
+	void rotate90() OVERRIDE;
 };
 
 
@@ -48,16 +48,16 @@ class async_wolke_t : public obj_t
 {
 public:
 	async_wolke_t(loadsave_t *file);
-	typ get_typ() const { return async_wolke; }
-	image_id get_image() const { return IMG_EMPTY; }
+	typ get_typ() const OVERRIDE { return async_wolke; }
+	image_id get_image() const OVERRIDE { return IMG_EMPTY; }
 };
 
 class raucher_t : public obj_t
 {
 public:
 	raucher_t(loadsave_t *file);
-	typ get_typ() const { return raucher; }
-	image_id get_image() const { return IMG_EMPTY; }
+	typ get_typ() const OVERRIDE { return raucher; }
+	image_id get_image() const OVERRIDE { return IMG_EMPTY; }
 };
 
 #endif
