@@ -24,8 +24,8 @@ public:
 
 	void change_pos(koord3d k);
 
-	const char *get_name() const {return "Zeiger";}
-	typ get_typ() const { return zeiger; }
+	const char *get_name() const OVERRIDE {return "Zeiger";}
+	typ get_typ() const OVERRIDE { return zeiger; }
 
 	/**
 	 * Set area to be marked around cursor
@@ -38,12 +38,14 @@ public:
 	/// set back image
 	void set_image( image_id b );
 	/// get back image
-	image_id get_image() const {return image;}
+	image_id get_image() const OVERRIDE {return image;}
 
 	/// set front image
 	void set_foreground_image( image_id b );
 	/// get front image
-	image_id get_front_image() const {return foreground_image;}
+	image_id get_front_image() const OVERRIDE {return foreground_image;}
+
+	bool has_managed_lifecycle() const OVERRIDE;
 };
 
 #endif
